<?php
/**
 * Register meta boxes
 *
 * Remember to change "your_prefix" to actual prefix in your project
 *
 * @param array $meta_boxes List of meta boxes
 *
 * @return array
 */
function plant_func_register_meta_boxes($meta_boxes)
{
    global $wp_registered_sidebars;
    /**
     * prefix of meta keys (optional)
     * Use underscore (_) at the beginning to make keys hidden
     * Alt.: You also can make prefix empty to disable it
     */
    $sidebars = array();
    if ($wp_registered_sidebars) {
        foreach ($wp_registered_sidebars as $key => $value) {
            $sidebars[$key] = $value['name'];
        }
    }
    // Better has an underscore as last sign
    $prefix = 'plant_';
    $layouts = array(
        '' => esc_html__('Fullwidth', 'plant'),
        'leftmain' => esc_html__('Left - Main Sidebar', 'plant'),
        'mainright' => esc_html__('Main - Right Sidebar', 'plant'),

    );
    $footers = plant_fnc_get_footer_profiles();
    $footers['global'] = esc_html__('Global', 'plant');

    // 1st meta box
    $meta_boxes[] = array(
        // Meta box id, UNIQUE per meta box. Optional since 4.1.5
        'id' => 'standard',
        // Meta box title - Will appear at the drag and drop handle bar. Required.
        'title' => esc_html__('Page Layout Setting', 'plant'),
        // Post types, accept custom post types as well - DEFAULT is 'post'. Can be array (multiple post types) or string (1 post type). Optional.
        'post_types' => array('page'),
        // Where the meta box appear: normal (default), advanced, side. Optional.
        'context' => 'normal',
        // Order of meta box: high (default), low. Optional.
        'priority' => 'low',
        // Auto save: true, false (default). Optional.
        'autosave' => true,
        // List of meta fields
        'fields' => array(

            // CHECKBOX
            array(
                'name' => esc_html__('Enable Fullwidth Layout', 'plant'),
                'id' => "{$prefix}enable_fullwidth_layout",
                'type' => 'checkbox',
                // Value can be 0 or 1
                'std' => 0,
            ),
            // HEADER SELECT BOX
            array(
                'name' => esc_html__('Header Layout', 'plant'),
                'id' => "{$prefix}header_layout",
                'type' => 'select',
                // Array of 'value' => 'Label' pairs for select box
                'options' => plant_fnc_get_header_layouts(),
                // Select multiple values, optional. Default is false.
                'multiple' => false,
                'std' => '',
                'placeholder' => esc_html__('Select option', 'plant'),
            ),

            array(
                'name' => esc_html__('Footer Layout', 'plant'),
                'id' => "{$prefix}footer_profile",
                'type' => 'select',
                'options' => $footers,
                'multiple' => false,
                'placeholder' => esc_html__('Select option', 'plant'),
            ),

            // CHECKBOX
            array(
                'name' => esc_html__('Disable Breadscrumb', 'plant'),
                'id' => "{$prefix}disable_breadscrumb",
                'type' => 'checkbox',
                // Value can be 0 or 1
                'std' => 1,
            ),
            array(
                'name' => esc_html__('Background for Breadscrumb', 'plant'),
                'id' => "{$prefix}background_breadscrumbs",
                'type' => 'single_image',
                'std' => ''
            ),
            array(
                'name' => esc_html__('Color for breadscrumbs', 'plant'),
                'id' => "{$prefix}color_breadscrumb",
                'type' => 'color',
                'description' => esc_html__('Used for breadscrumbs', 'plant'),
            ),
            array(
                'name' => esc_html__('Style breadscrumbs', 'plant'),
                'id' => "{$prefix}stylebreadscrumbs",
                'type' => 'select',
                // Array of 'value' => 'Label' pairs for select box
                'options' => array(
                    'default' => esc_html__('Default', 'plant'),
                    'parallax' => esc_html__('Parallax with image', 'plant'),
                ),
                // Select multiple values, optional. Default is false.
                'multiple' => false,
                'std' => 'default',
            ),

            array(
                'name' => esc_html__('Layout', 'plant'),
                'id' => "{$prefix}page_layout",
                'type' => 'select',
                // Array of 'value' => 'Label' pairs for select box
                'options' => $layouts,
                // Select multiple values, optional. Default is false.
                'multiple' => false,
                'std' => '',

            ),

            // HEADER SELECT BOX
            array(
                'name' => esc_html__('Left Sidebar', 'plant'),
                'id' => "{$prefix}leftsidebar",
                'type' => 'select',
                // Array of 'value' => 'Label' pairs for select box
                'options' => $sidebars,
                // Select multiple values, optional. Default is false.
                'multiple' => false,
                'std' => '',
                'placeholder' => esc_html__('Global', 'plant'),
            ),

            // HEADER SELECT BOX
            array(
                'name' => esc_html__('Right Sidebar', 'plant'),
                'id' => "{$prefix}rightsidebar",
                'type' => 'select',
                // Array of 'value' => 'Label' pairs for select box
                'options' => $sidebars,
                // Select multiple values, optional. Default is false.
                'multiple' => false,
                'std' => '',
                'placeholder' => esc_html__('Global', 'plant'),
            ),
            // HEADER SELECT BOX
            array(
                'name' => esc_html__('Addition class', 'plant'),
                'id' => "{$prefix}additionclass",
                'type' => 'select',
                // Array of 'value' => 'Label' pairs for select box
                'options' => array(
                    'home-background' => esc_html__('Home Background', 'plant'),
                    'home-border-15' => esc_html__('Home Border 15px', 'plant'),
                    'home-margin-left' => esc_html__('Home Margin Left', 'plant'),
                    'home-margin-content' => esc_html__('Home Margin content 30', 'plant'),
                    'home-margin-footer' => esc_html__('Home Margin footer 30', 'plant'),
                    'home-box' => esc_html__('Home Box', 'plant'),
                ),
                // Select multiple values, optional. Default is false.
                'multiple' => false,
                'std' => '',
                'placeholder' => esc_html__('None', 'plant'),
            ),
            array(
                'name' => esc_html__('Border color for home', 'plant'),
                'id' => "{$prefix}border_color_home",
                'type' => 'color',
                'description' => esc_html__('Used for Home Border', 'plant'),
            ),

        ),
        'validation' => array()
    );

    return $meta_boxes;
}

add_filter('rwmb_meta_boxes', 'plant_func_register_meta_boxes', 102);


function plant_func_register_postformat_meta_boxes($meta_boxes)
{

    // Better has an underscore as last sign
    $prefix = 'plant_';

    $layouts = array(
        '' => esc_html__('Fullwidth', 'plant'),
        'leftmain' => esc_html__('Left - Main Sidebar', 'plant'),
        'mainright' => esc_html__('Main - Right Sidebar', 'plant'),

    );

    // 1st meta box
    $meta_boxes[] = array(
        // Meta box id, UNIQUE per meta box. Optional since 4.1.5
        'id' => 'post_format_standard_post_meta',
        // Meta box title - Will appear at the drag and drop handle bar. Required.
        'title' => esc_html__('Format Setting', 'plant'),
        // Post types, accept custom post types as well - DEFAULT is 'post'. Can be array (multiple post types) or string (1 post type). Optional.
        'post_types' => array('post'),
        // Where the meta box appear: normal (default), advanced, side. Optional.
        'context' => 'normal',
        // Order of meta box: high (default), low. Optional.
        'priority' => 'low',
        // Auto save: true, false (default). Optional.
        'autosave' => true,
        // List of meta fields
        'fields' => array(

            // CHECKBOX
            array(
                'id' => "{$prefix}image_files",
                'name' => esc_html__('Image for header', 'plant'),
                'type' => 'file_advanced',
                'description' => esc_html__('Select one images to show', 'plant'),
            ),
            array(
                'id' => "{$prefix}gallery_files",
                'name' => esc_html__('Images Gallery', 'plant'),
                'type' => 'file_advanced',
                'description' => esc_html__('Select one or more images to show as gallery', 'plant'),
            ),

            array(
                'id' => "{$prefix}video_link",
                'name' => esc_html__('Video Link', 'plant'),
                'type' => 'oembed',
                'description' => esc_html__('Video Link', 'plant'),
            ),

            array(
                'id' => "{$prefix}link_text",
                'name' => esc_html__('Link Text', 'plant'),
                'type' => 'text',
                'description' => esc_html__('Link Text', 'plant'),
            ),
            array(
                'id' => "{$prefix}quote",
                'name' => esc_html__('Quote Text', 'plant'),
                'type' => 'text',
                'description' => esc_html__('Quote text', 'plant'),
            ),
            array(
                'id' => "{$prefix}link_link",
                'name' => esc_html__('Link To Redirect', 'plant'),
                'type' => 'text',
                'description' => esc_html__('Link To Redirect', 'plant'),
            ),

            array(
                'id' => "{$prefix}audio_link",
                'name' => esc_html__('Audio Link', 'plant'),
                'type' => 'text',
                'description' => esc_html__('Select one or more images to show as gallery', 'plant'),
            ),
        ),
        'validation' => array()
    );

    return $meta_boxes;
}


function plant_func_standard_post_meta($post_id)
{

    global $post;
    $prefix = 'plant_';
    $type = get_post_format();

    $old = array(
        'gallery_files',
        'video_link',
        'link_text',
        'link_link',
        'audio_link',
        'quote'
    );

    $data = array('gallery' => array('gallery_files'),
        'video' => array('video_link'),
        'audio' => array('audio_link'),
        'quote' => array('quote'),
        'link' => array('link_link', 'link_text'));

    $new = array();

    if (isset($data[$type])) {
        foreach ($data[$type] as $key => $value) {
            $new[$prefix . $value] = $_POST[$prefix . $value];
        }
    }


    foreach ($old as $key => $value) {
        if (isset($_POST[$prefix . $value])) {
            unset($_POST[$prefix . $value]);
        }
    }
    if ($new) {
        $_POST = array_merge($_POST, $new);
    }
    // echo get_post_format();


}

add_action("rwmb_post_format_standard_post_meta_before_save_post", 'plant_func_standard_post_meta', 9);

add_filter('rwmb_meta_boxes', 'plant_func_register_postformat_meta_boxes', 100);


//fix testimonial metabox
function plant_fnc_metaboxes_testimonial_fields()
{
    /**
     * prefix of meta keys (optional)
     * Use underscore (_) at the beginning to make keys hidden
     * Alt.: You also can make prefix empty to disable it
     */

    // Better has an underscore as last sign
    $prefix = 'testimonials_';
    $fields = array(
        // COLOR
        array(
            'name' => esc_html__('Name', 'plant'),
            'id' => "{$prefix}name",
            'type' => 'text',
            'description' => esc_html__('Enter name ', 'plant')
        ),
        array(
            'name' => esc_html__('Job', 'plant'),
            'id' => "{$prefix}job",
            'type' => 'text',
            'description' => esc_html__('Enter Job example CEO, CTO', 'plant')
        ),


        array(
            'name' => esc_html__('Link', 'plant'),
            'id' => "{$prefix}link",
            'type' => 'text',
            'description' => esc_html__('Enter Link to this personal', 'plant')
        ),


    );
    return apply_filters('plant_fnc_metaboxes_testimonial_fields', $fields);
}

/**
 *
 */
function plant_fnc_testimonials_register_meta_boxes($meta_boxes)
{

    // 1st meta box
    $meta_boxes[] = array(
        // Meta box id, UNIQUE per meta box. Optional since 4.1.5
        'id' => 'standard',
        // Meta box title - Will appear at the drag and drop handle bar. Required.
        'title' => esc_html__('Testimonials Info', 'plant'),
        // Post types, accept custom post types as well - DEFAULT is 'post'. Can be array (multiple post types) or string (1 post type). Optional.
        'post_types' => array('testimonial'),
        // Where the meta box appear: normal (default), advanced, side. Optional.
        'context' => 'normal',
        // Order of meta box: high (default), low. Optional.
        'priority' => 'low',
        // Auto save: true, false (default). Optional.
        'autosave' => true,
        // List of meta fields
        'fields' => plant_fnc_metaboxes_testimonial_fields()
    );

    return $meta_boxes;
}

/**
 * Register Metabox
 */

add_filter('rwmb_meta_boxes', 'plant_fnc_testimonials_register_meta_boxes', 15);