<?php
/**
 * $Desc
 *
 * @version    $Id$
 * @package    plant
 * @author     ENGOTHEME Team <engotheme@gmail.com?>
 * @copyright  Copyright (C) 2018 engotheme.com. All Rights Reserved.
 * @license    GNU/GPL v2 or later http://www.gnu.org/licenses/gpl-2.0.html
 *
 * @website  https://engotheme.com/
 * @support  https://engotheme.com/
 */

/**
 * THEMEOCEAN Category Drop Down List Class
 * modified dropdown-pages from wp-includes/class-wp-customize-control.php
 *
 * @since THEMEOCEAN v1.0
 */
if (class_exists("WP_Customize_Control")) {


    class Plant_Sidebar_DropDown extends WP_Customize_Control
    {

        public function render_content()
        {

            global $wp_registered_sidebars;

            $output = array();

            $output[] = '<option value="">' . esc_html__('No Sidebar', 'plant') . '</option>';

            foreach ($wp_registered_sidebars as $sidebar) {
                $selected = ($this->value() == $sidebar['id']) ? ' selected="selected" ' : '';
                $output[] = '<option value="' . $sidebar['id'] . '" ' . $selected . '>' . $sidebar['name'] . '</option>';
            }

            $dropdown = '<select>' . implode(" ", $output) . '</select>';
            $dropdown = str_replace('<select', '<select ' . $this->get_link(), $dropdown);

            printf(
                '<label class="customize-control-select"><span class="customize-control-title">%s</span> %s</label>',
                $this->label,
                $dropdown
            );

        }
    }

    ///
    class Plant_Layout_DropDown extends WP_Customize_Control
    {
        public $type = "PBR_Layout";

        public function render_content()
        {

            $layouts = array(
                'fullwidth' => esc_html__('Full width', 'plant'),
                'leftmain' => esc_html__('Left - Main Sidebar', 'plant'),
                'mainright' => esc_html__('Main - Right Sidebar', 'plant'),

            );
            printf(
                '<label class="customize-control-select"><span class="customize-control-title">%s</span>',
                $this->label

            );
            ?>
            <div class="page-layout">


            <?php
            $output = array();

            foreach ($layouts as $key => $layout) {
                $v = $this->value() ? $this->value() : 'fullwidth';
                $selected = ($v == $key) ? ' selected="selected" ' : '';
                $output[] = '<option value="' . $key . '" ' . $selected . '>' . $layout . '</option>';
            }

            $dropdown = '<select>' . implode(" ", $output) . '</select>';
            $dropdown = str_replace('<select', '<select ' . $this->get_link(), $dropdown);

            printf(
                '%s</label>',

                $dropdown
            ) . '</div>';
        }
    }

}
if (class_exists('WP_Customize_Control')) {
    class Plant_Customize_Dropdown_Categories_Control extends WP_Customize_Control
    {
        public $type = 'dropdown-categories';

        public function render_content()
        {
            $dropdown = wp_dropdown_categories(
                array(
                    'name' => '_customize-dropdown-categories-' . $this->id,
                    'echo' => 0,
                    'hide_empty' => false,
                    'show_option_none' => '&mdash; ' . esc_html__('Select', 'plant') . ' &mdash;',
                    'hide_if_empty' => false,
                    'selected' => $this->value(),
                )
            );

            $dropdown = str_replace('<select', '<select ' . $this->get_link(), $dropdown);

            printf(
                '<label class="customize-control-select"><span class="customize-control-title">%s</span> %s</label>',
                $this->label,
                $dropdown
            );
        }
    }
}

/**
 * THEMEOCEAN TextArea Control Class
 * create custom textarea input field
 *
 * @since THEMEOCEAN v0.5
 **/

if (class_exists('WP_Customize_Control')) {
    # Adds textarea support to the theme customizer
    class Plant_TextAreaControl extends WP_Customize_Control
    {
        public $type = 'textarea'; # can change to 'number' for input[type=number] field

        public function __construct($manager, $id, $args = array())
        {
            $this->statuses = array('' => esc_html__('Default', 'plant'));
            parent::__construct($manager, $id, $args);
        }

        public function render_content()
        {
            echo trim('<label>
                <span class="customize-control-title">' . esc_html($this->label) . '</span>
                <textarea rows="5" style="width:100%;" ');
            $this->link();
            echo trim('>' . esc_textarea($this->value()) . '</textarea>
                </label>');
        }
    }

}

if (class_exists('WP_Customize_Control')) {


    /**
     * Class to create a custom tags control
     */
    class Plant_Text_Editor_Custom_Control extends WP_Customize_Control
    {
        /**
         * Render the content on the theme customizer page
         */
        public function render_content()
        {
            ?>
            <label>
                <span class="customize-text_editor"><?php echo esc_html($this->label); ?></span>
                <?php
                $settings = array(
                    'textarea_name' => $this->id
                );

                wp_editor($this->value(), $this->id, $settings);
                ?>
            </label>
            <?php
        }
    }

}

/**
 * THEMEOCEAN Google Front Control Class
 *
 * @since THEMEOCEAN v2.1
 **/
if (class_exists('WP_Customize_Control')) {
    # Adds textarea support to the theme customizer
    class Plant_GoogleFontControl extends WP_Customize_Control
    {

        private $fonts = false;

        public function __construct($manager, $id, $args = array(), $options = array())
        {
            $this->fonts = get_transient('google_font_names_');

            if (!is_array($this->fonts))
                $this->fonts = $this->get_font_names();

            if (!$this->fonts) return;

            parent::__construct($manager, $id, $args);

        }

        public function render_content()
        {
            if (!empty($this->fonts)) { ?>
                <label>
                    <span class="customize-category-select-control"><?php echo esc_html($this->label); ?></span>
                    <select <?php $this->link(); ?>>
                        <?php
                        foreach ($this->fonts as $key => $value) {
                            printf('<option value="%s">%s</option>',
                                $key,
                                $value);
                        }
                        ?>
                    </select>
                </label>
                <?php
            }
        }

        public function get_font_names()
        {

            $font_name_list = get_transient('google_font_names_');

            if ($font_name_list)
                return $font_name_list;

            $json_name_list = @wp_remote_get('https://www.googleapis.com/webfonts/v1/webfonts?sort=popularity');

            if (!isset($json_name_list))
                return;

            $decoded_name_list = @json_decode($json_name_list['body']);

            $font_name_list['none'] = 'none';

            if (is_object($decoded_name_list))
                foreach ($decoded_name_list->items as $font_name)
                    $font_name_list[str_replace(' ', '+', $font_name->family)] = $font_name->family;

            set_transient('google_font_names_', $font_name_list, 60 * 60 * 24);
            return $font_name_list;
        }
    }
}
?>
<?php
/**
 * Plant Customizer support
 *
 * @package ENGOTHEME
 * @subpackage Plant
 * @since Plant 1.0
 */

/**
 * Implement Customizer additions and adjustments.
 *
 * @since Plant 1.0
 *
 * @param WP_Customize_Manager $wp_customize Customizer object.
 */
function plant_fnc_customize_register($wp_customize)
{
    // Add postMessage support for site title and description.
    $wp_customize->get_setting('blogname')->transport = 'postMessage';
    $wp_customize->get_setting('blogdescription')->transport = 'postMessage';
    $wp_customize->get_setting('header_textcolor')->transport = 'postMessage';

    // Rename the label to "Site Title Color" because this only affects the site title in this theme.
    $wp_customize->get_control('header_textcolor')->label = esc_html__('Site Title Color', 'plant');

    // Rename the label to "Display Site Title & Tagline" in order to make this option extra clear.
    $wp_customize->get_control('display_header_text')->label = esc_html__('Display Site Title &amp; Tagline', 'plant');

    // Add custom description to Colors and Background controls or sections.
    if (property_exists($wp_customize->get_control('background_color'), 'description')) {
        $wp_customize->get_control('background_color')->description = esc_html__('May only be visible on wide screens.', 'plant');
        $wp_customize->get_control('background_image')->description = esc_html__('May only be visible on wide screens.', 'plant');
    } else {
        $wp_customize->get_section('colors')->description = esc_html__('Background may only be visible on wide screens.', 'plant');
        $wp_customize->get_section('background_image')->description = esc_html__('Background may only be visible on wide screens.', 'plant');
    }

    $wp_customize->add_setting('link_color', array(
        'default' => get_option('link_color'),
        'type' => 'option',
        'capability' => 'manage_options',
        'transport' => 'postMessage',
        'sanitize_callback' => 'sanitize_text_field',
    ));

    $wp_customize->add_control('link_color', array(
        'label' => esc_html__('Link Color', 'plant'),
        'section' => 'colors',
        'type' => 'color',
    ));

    $wp_customize->add_setting('text_color', array(
        'default' => get_option('text_color'),
        'type' => 'option',
        'capability' => 'manage_options',
        'transport' => 'postMessage',
        'sanitize_callback' => 'sanitize_text_field',
    ));

    $wp_customize->add_control('text_color', array(
        'label' => esc_html__('Text Color', 'plant'),
        'section' => 'colors',
        'type' => 'color',
    ));

    $wp_customize->add_setting('color_price', array(
        'default' => get_option('color_price'),
        'type' => 'option',
        'capability' => 'manage_options',
        'transport' => 'postMessage',
        'sanitize_callback' => 'sanitize_text_field',
    ));

    $wp_customize->add_control('color_price', array(
        'label' => esc_html__('Color Price', 'plant'),
        'section' => 'colors',
        'type' => 'color',
    ));

    $wp_customize->add_setting('color_price_old', array(
        'default' => get_option('color_price_old'),
        'type' => 'option',
        'capability' => 'manage_options',
        'transport' => 'postMessage',
        'sanitize_callback' => 'sanitize_text_field',
    ));

    $wp_customize->add_control('color_price_old', array(
        'label' => esc_html__('Color Price Old', 'plant'),
        'section' => 'colors',
        'type' => 'color',
    ));

    $wp_customize->add_setting('topbar_bg', array(
        'default' => get_option('topbar_bg'),
        'type' => 'option',
        'capability' => 'manage_options',
        'transport' => 'postMessage',
        'sanitize_callback' => 'sanitize_text_field'
    ));

    $wp_customize->add_control('topbar_bg', array(
        'label' => esc_html__('Topbar Background', 'plant'),
        'section' => 'colors',
        'type' => 'color',
    ));

    $wp_customize->add_setting('topbar_color', array(
        'default' => get_option('footer_color'),
        'type' => 'option',
        'capability' => 'manage_options',
        'transport' => 'postMessage',
        'sanitize_callback' => 'sanitize_text_field'
    ));

    $wp_customize->add_control('topbar_color', array(
        'label' => esc_html__('Topbar Text Color', 'plant'),
        'section' => 'colors',
        'type' => 'color',
    ));

    $wp_customize->add_setting('topbar_bgcart', array(
        'default' => get_option('footer_color'),
        'type' => 'option',
        'capability' => 'manage_options',
        'transport' => 'postMessage',
        'sanitize_callback' => 'sanitize_text_field'
    ));

    $wp_customize->add_control('topbar_bgcart', array(
        'label' => esc_html__('Topbar bg cart', 'plant'),
        'section' => 'colors',
        'type' => 'color',
    ));

    $wp_customize->add_setting('page_bg', array(
        'default' => get_option('page_bg'),
        'type' => 'option',
        'capability' => 'manage_options',
        'transport' => 'postMessage',
        'sanitize_callback' => 'sanitize_text_field'
    ));

    $wp_customize->add_control('page_bg', array(
        'label' => esc_html__('Page Container Background', 'plant'),
        'section' => 'colors',
        'type' => 'color',
        'default' => '#FFFFFF'
    ));

    $wp_customize->add_setting('footer_bg', array(
        'default' => get_option('footer_bg'),
        'type' => 'option',
        'capability' => 'manage_options',
        'transport' => 'postMessage',
        'sanitize_callback' => 'sanitize_text_field'
    ));

    $wp_customize->add_control('footer_bg', array(
        'label' => esc_html__('Footer Background', 'plant'),
        'section' => 'colors',
        'type' => 'color',
    ));

    $wp_customize->add_setting('footer_heading_color', array(
        'default' => get_option('footer_heading_color'),
        'type' => 'option',
        'capability' => 'manage_options',
        'transport' => 'postMessage',
        'sanitize_callback' => 'sanitize_text_field'
    ));

    $wp_customize->add_control('footer_heading_color', array(
        'label' => esc_html__('Footer Heading Color', 'plant'),
        'section' => 'colors',
        'type' => 'color',
    ));

    $wp_customize->add_setting('footer_color', array(
        'default' => get_option('footer_color'),
        'type' => 'option',
        'capability' => 'manage_options',
        'transport' => 'postMessage',
        'sanitize_callback' => 'sanitize_text_field'
    ));

    $wp_customize->add_control('footer_color', array(
        'label' => esc_html__('Footer Text Color', 'plant'),
        'section' => 'colors',
        'type' => 'color',
    ));

    $wp_customize->add_setting('header_image_link', array(
        'default' => get_option('footer_color'),
        'type' => 'option',
        'capability' => 'manage_options',
        'transport' => 'postMessage',
        'sanitize_callback' => 'esc_url_raw',
        'default' => '#'
    ));

    $wp_customize->add_control('header_image_link', array(
        'label' => esc_html__('Image Link', 'plant'),
        'section' => 'header_image',
        'type' => 'text',
        'default' => '#'
    ));
}

add_action('customize_register', 'plant_fnc_customize_register');


function plant_fnc_sanitize_textarea($content)
{
    return wp_kses_post(trim($content));
}

/**
 *
 */
add_action('customize_register', 'plant_fnc_cst_customizer');

function plant_fnc_cst_customizer($wp_customize)
{

    # General Settings
    // Panel Header
    $wp_customize->add_section('pbr_cst_general_settings', array(
        'title' => esc_html__('General Settings', 'plant'),
        'description' => esc_html__('Website General Settings', 'plant'),
        'transport' => 'postMessage',
        'priority' => 10,
    ));

    // Parameter Options
    $wp_customize->add_setting('blogname', array(
        'default' => get_option('blogname'),
        'type' => 'option',
        'capability' => 'manage_options',
        'transport' => 'postMessage',
        'sanitize_callback' => 'sanitize_text_field'
    ));

    $wp_customize->add_control('blogname', array(
        'label' => esc_html__('Site Title', 'plant'),
        'section' => 'pbr_cst_general_settings',
        'priority' => 1,
    ));

    //
    $wp_customize->add_setting('blogdescription', array(
        'default' => get_option('blogdescription'),
        'type' => 'option',
        'capability' => 'manage_options',
        'transport' => 'postMessage',
        'sanitize_callback' => 'sanitize_text_field'
    ));

    $wp_customize->add_control('blogdescription', array(
        'label' => esc_html__('Tagline', 'plant'),
        'section' => 'pbr_cst_general_settings',
        'priority' => 2,
    ));

    // 
    $wp_customize->add_setting('display_header_text', array(
        'default' => 1,
        'type' => 'option',
        'capability' => 'manage_options',
        'transport' => 'postMessage',
        'sanitize_callback' => 'sanitize_text_field'
    ));
    $wp_customize->add_control('display_header_text', array(
        'settings' => 'header_textcolor',
        'label' => esc_html__('Show Title & Tagline', 'plant'),
        'section' => 'pbr_cst_general_settings',
        'type' => 'checkbox',
        'priority' => 4,
    ));


    /* 
     * Custom Logo 
     */
    if (version_compare($GLOBALS['wp_version'], '4.5', '<')) {
        $wp_customize->add_setting('pbr_theme_options[logo]', array(
            'default' => '',
            'type' => 'option',
            'capability' => 'manage_options',
            'sanitize_callback' => 'esc_url_raw',
        ));

        $wp_customize->add_control(new WP_Customize_Image_Control($wp_customize, 'pbr_theme_options[logo]', array(
            'label' => esc_html__('Logo', 'plant'),
            'section' => 'pbr_cst_general_settings',
            'settings' => 'pbr_theme_options[logo]',
            'priority' => 10,
        )));
        $wp_customize->add_setting('pbr_theme_options[logo_white]', array(
            'default' => '',
            'type' => 'option',
            'capability' => 'manage_options',
            'sanitize_callback' => 'esc_url_raw',
        ));

        $wp_customize->add_control(new WP_Customize_Image_Control($wp_customize, 'pbr_theme_options[logo_white]', array(
            'label' => esc_html__('Logo White', 'plant'),
            'section' => 'pbr_cst_general_settings',
            'settings' => 'pbr_theme_options[logo_white]',
            'priority' => 11,
        )));
    }
    $wp_customize->add_setting('pbr_theme_options[logo_white]', array(
        'default' => '',
        'type' => 'option',
        'capability' => 'manage_options',
        'sanitize_callback' => 'esc_url_raw',
    ));

    $wp_customize->add_control(new WP_Customize_Image_Control($wp_customize, 'pbr_theme_options[logo_white]', array(
        'label' => esc_html__('Logo White', 'plant'),
        'section' => 'title_tagline',
        'settings' => 'pbr_theme_options[logo_white]',
        'priority' => 10,
    )));

    //
    $wp_customize->add_setting('pbr_theme_options[copyright_text]', array(
        'default' => esc_html__('Copyright 2018 - Plant - All Rights Reserved.', 'plant'),
        'type' => 'option',
        'transport' => 'refresh',
        'sanitize_callback' => 'plant_fnc_sanitize_textarea',
    ));

    $wp_customize->add_control(new Plant_TextAreaControl($wp_customize, 'pbr_theme_options[copyright_text]', array(
        'label' => esc_html__('Copyright text', 'plant'),
        'section' => 'pbr_cst_general_settings',
        'settings' => 'pbr_theme_options[copyright_text]',
        'priority' => 12,
    )));

    /* 
     * Custom Logo 
     */
    $wp_customize->add_setting('pbr_theme_options[breadcrumb_image]', array(
        'default' => '',
        'type' => 'option',
        'capability' => 'manage_options',
        'sanitize_callback' => 'esc_url_raw',
    ));

    $wp_customize->add_control(new WP_Customize_Image_Control($wp_customize, 'pbr_theme_options[breadcrumb_image]', array(
        'label' => esc_html__('Breadcrumb Image', 'plant'),
        'section' => 'pbr_cst_general_settings',
        'settings' => 'pbr_theme_options[breadcrumb_image]',
        'priority' => 10,
    )));
    /***************************************************************************
     * Theme Settings
     ***************************************************************************/


    /**
     * General Setting
     */
    $wp_customize->add_section('ts_general_settings', array(
        'priority' => 12,
        'capability' => 'edit_theme_options',
        'theme_supports' => '',
        'title' => esc_html__('Themes And Layouts Setting', 'plant'),
        'description' => '',
    ));

    //
    $wp_customize->add_setting('pbr_theme_options[skin]', array(
        'type' => 'option',
        'capability' => 'manage_options',
        'default' => 'default',
        'sanitize_callback' => 'sanitize_text_field'
    ));

    $wp_customize->add_control('pbr_theme_options[skin]', array(
        'label' => esc_html__('Active Skin', 'plant'),
        'section' => 'ts_general_settings',
        'type' => 'select',
        'choices' => plant_fnc_cst_skins(),
    ));
    if (class_exists('PbrThemerSetting')):
        $wp_customize->add_setting('pbr_theme_options[headerlayout]', array(
            'type' => 'option',
            'capability' => 'manage_options',
            'default' => '',
            'sanitize_callback' => 'sanitize_text_field'
        ));

        $wp_customize->add_control('pbr_theme_options[headerlayout]', array(
            'label' => esc_html__('Header Layout Style', 'plant'),
            'section' => 'ts_general_settings',
            'type' => 'select',
            'choices' => array('' => 'Default'),
            'choices' => plant_fnc_get_header_layouts(),
        ));


        $wp_customize->add_setting('pbr_theme_options[footer-style]', array(
            'type' => 'option',
            'capability' => 'manage_options',
            'default' => '',
            'sanitize_callback' => 'sanitize_text_field'
        ));

        $wp_customize->add_control('pbr_theme_options[footer-style]', array(
            'label' => esc_html__('Footer Styles Builder', 'plant'),
            'section' => 'ts_general_settings',
            'type' => 'select',
            'choices' => plant_fnc_get_footer_profiles()
        ));
    endif;


    /******************************************************************
     * Social share
     ******************************************************************/
    $wp_customize->add_section('social_share_settings', array(
        'priority' => 50,
        'capability' => 'edit_theme_options',
        'theme_supports' => '',
        'title' => esc_html__('Social Share setting', 'plant'),
        'description' => '',
    ));

    // Share facebook
    plant_fnc_social_config($wp_customize, 'facebook_share_blog', esc_html__('Share facebook ', 'plant'), 'social_share_settings');
    //share twitter
    plant_fnc_social_config($wp_customize, 'twitter_share_blog', esc_html__('Share twitter ', 'plant'), 'social_share_settings');
    //share linkedin
    plant_fnc_social_config($wp_customize, 'linkedin_share_blog', esc_html__('Share linkedin ', 'plant'), 'social_share_settings');
    //share tumblr
    plant_fnc_social_config($wp_customize, 'tumblr_share_blog', esc_html__('Share tumblr ', 'plant'), 'social_share_settings');
    //share google plus
    plant_fnc_social_config($wp_customize, 'google_share_blog', esc_html__('Share google plus ', 'plant'), 'social_share_settings');
    //share pinterest
    plant_fnc_social_config($wp_customize, 'pinterest_share_blog', esc_html__('Share pinterest ', 'plant'), 'social_share_settings');
    //share mail
    plant_fnc_social_config($wp_customize, 'mail_share_blog', esc_html__('Share mail ', 'plant'), 'social_share_settings');


    /******************************************************************
     * Navigation
     ******************************************************************/

    # Sticky Top Bar Option
    $wp_customize->add_setting('pbr_theme_options[verticalmenu]', array(
        'capability' => 'edit_theme_options',
        'type' => 'option',
        'sanitize_callback' => 'sanitize_text_field'
    ));

    $wp_customize->add_control('pbr_theme_options[verticalmenu]', array(
        'settings' => 'pbr_theme_options[verticalmenu]',
        'label' => esc_html__('Vertical Megamenu', 'plant'),
        'section' => 'nav',
        'type' => 'select',
        'choices' => plant_fnc_get_menugroups(),
    ));


    # Sticky Top Bar Option
    $wp_customize->add_setting('pbr_theme_options[megamenu-is-sticky]', array(
        'capability' => 'edit_theme_options',
        'type' => 'option',
        'sanitize_callback' => 'sanitize_text_field'
    ));

    $wp_customize->add_control('pbr_theme_options[megamenu-is-sticky]', array(
        'settings' => 'pbr_theme_options[megamenu-is-sticky]',
        'label' => esc_html__('Sticky Top Bar', 'plant'),
        'section' => 'nav',
        'type' => 'checkbox',
        'transport' => 4,
    ));

    $wp_customize->add_setting('pbr_theme_options[megamenu-duration]', array(
        'type' => 'option',
        'capability' => 'manage_options',
        'default' => '300',
        'sanitize_callback' => 'sanitize_text_field'
    ));

    $wp_customize->add_control('pbr_theme_options[megamenu-duration]', array(
        'label' => esc_html__('Megamenu Duration', 'plant'),
        'section' => 'nav',
        'type' => 'text'
    ));

    /*****************************************************************
     * Front Page Settings Panel
     *****************************************************************/
    $wp_customize->add_section('static_front_page', array(
        'title' => esc_html__('Front Page Settings', 'plant'),
        'priority' => 120,
        'description' => esc_html__('Your theme supports a static front page.', 'plant'),
    ));

    $wp_customize->add_setting('pbr_theme_options[sidebar_position]', array(
        'default' => 'left',
        'capability' => 'edit_theme_options',
        'type' => 'option',
        'sanitize_callback' => 'sanitize_text_field'
    ));

    $wp_customize->add_control('pbr_theme_options[sidebar_position]', array(
        'type' => 'radio',
        'label' => 'Sidebar Position',
        'section' => 'static_front_page',
        'priority' => 1,
        'choices' => array(
            'left' => 'Left',
            'right' => 'Right',
        ),
    ));

    $wp_customize->add_setting('show_on_front', array(
        'default' => get_option('show_on_front'),
        'capability' => 'manage_options',
        'type' => 'option',
        //  'theme_supports' => 'static-front-page',
        'sanitize_callback' => 'sanitize_text_field'
    ));

    $wp_customize->add_control('show_on_front', array(
        'label' => esc_html__('Front page displays', 'plant'),
        'section' => 'static_front_page',
        'type' => 'radio',
        'choices' => array(
            'posts' => esc_html__('Your latest posts', 'plant'),
            'page' => esc_html__('A static page', 'plant'),
        ),
    ));

    $wp_customize->add_setting('page_on_front', array(
        'type' => 'option',
        'capability' => 'manage_options',
        'sanitize_callback' => 'sanitize_text_field'
    ));

    $wp_customize->add_control('page_on_front', array(
        'label' => esc_html__('Front page', 'plant'),
        'section' => 'static_front_page',
        'type' => 'dropdown-pages',
    ));

    $wp_customize->add_setting('page_for_posts', array(
        'type' => 'option',
        'capability' => 'manage_options',
        //  'theme_supports' => 'static-front-page',
        'sanitize_callback' => 'sanitize_text_field'
    ));

    $wp_customize->add_control('page_for_posts', array(
        'label' => esc_html__('Posts page', 'plant'),
        'section' => 'static_front_page',
        'type' => 'dropdown-pages',
    ));


    /* 
     /*****************************************************************
     * Front Page Settings Panel
     *****************************************************************/
    $wp_customize->add_section('newsletter_setting', array(
        'title' => esc_html__('Newsletter', 'plant'),
        'priority' => 120,
        'description' => esc_html__('Newsletter', 'plant'),
    ));


    $wp_customize->add_setting('pbr_theme_options[newsletter_image]', array(
        'default' => '',
        'type' => 'option',
        'capability' => 'manage_options',
        'sanitize_callback' => 'esc_url_raw',
    ));

    $wp_customize->add_control(new WP_Customize_Image_Control($wp_customize, 'pbr_theme_options[newsletter_image]', array(
        'label' => esc_html__('Image', 'plant'),
        'section' => 'newsletter_setting',
        'settings' => 'pbr_theme_options[newsletter_image]',
        'priority' => 122,
    )));

    $wp_customize->add_setting('pbr_theme_options[newsletter_title]', array(
        'type' => 'option',
        'capability' => 'manage_options',
        'sanitize_callback' => 'sanitize_text_field',
        'default' => esc_html__('Sign up for emails', 'plant'),
    ));

    $wp_customize->add_control('pbr_theme_options[newsletter_title]', array(
        'label' => esc_html__('Newsletter title', 'plant'),
        'section' => 'newsletter_setting',
        'priority' => 123
    ));
    $wp_customize->add_setting('pbr_theme_options[newsletter_subtitle]', array(
        'type' => 'option',
        'capability' => 'manage_options',
        'sanitize_callback' => 'sanitize_text_field',
        'default' => esc_html__('Get 20% off your entire purchase.', 'plant'),
    ));

    $wp_customize->add_control('pbr_theme_options[newsletter_subtitle]', array(
        'label' => esc_html__('Newsletter Sub title', 'plant'),
        'section' => 'newsletter_setting',
        'priority' => 123
    ));
    $wp_customize->add_setting('pbr_theme_options[newsletter_desc]', array(
        'type' => 'option',
        'capability' => 'manage_options',
        'sanitize_callback' => 'sanitize_text_field',
        'default' => esc_html__('Subscribe to the Plant mailing list to receive updates on new arrivals, special offers and other discount information.', 'plant')
    ));

    $wp_customize->add_control('pbr_theme_options[newsletter_desc]', array(
        'label' => esc_html__('Newsletter Description', 'plant'),
        'section' => 'newsletter_setting',
        'priority' => 123
    ));
    $wp_customize->add_setting('pbr_theme_options[newsletter_form]', array(
        'type' => 'option',
        'capability' => 'manage_options',
        'sanitize_callback' => 'sanitize_text_field'
    ));

    $wp_customize->add_control('pbr_theme_options[newsletter_form]', array(
        'label' => esc_html__('Newsletter Form (Shorcode contact form 7 )', 'plant'),
        'section' => 'newsletter_setting',
        'priority' => 123
    ));
    //

    /*
    /*****************************************************************
    * Front Page Settings Panel
    *****************************************************************/
    $wp_customize->add_section('pages_setting', array(
        'title' => esc_html__('Page 404 Settings', 'plant'),
        'priority' => 120,
        'description' => esc_html__('page 404 setting', 'plant'),
    ));

    $wp_customize->add_setting('pbr_theme_options[footer-404]', array(
        'type' => 'option',
        'capability' => 'manage_options',
        'default' => 'default',
        'sanitize_callback' => 'sanitize_text_field'
    ));

    $wp_customize->add_control('pbr_theme_options[footer-404]', array(
        'label' => esc_html__('Footer Styles Builder', 'plant'),
        'section' => 'pages_setting',
        'type' => 'select',
        'choices' => plant_fnc_get_footer_profiles()
    ));
    $wp_customize->add_setting('pbr_theme_options[background_404]', array(
        'default' => '',
        'type' => 'option',
        'capability' => 'manage_options',
        'sanitize_callback' => 'esc_url_raw',
    ));

    $wp_customize->add_control(new WP_Customize_Image_Control($wp_customize, 'pbr_theme_options[background_404]', array(
        'label' => esc_html__('Background 404 Image', 'plant'),
        'section' => 'pages_setting',
        'settings' => 'pbr_theme_options[background_404]',
        'priority' => 122,
    )));
    //
}


function plant_fnc_social_config($wp_customize, $id, $name_social, $section)
{
    $wp_customize->add_setting('pbr_theme_options[' . $id . ']', array(
        'capability' => 'edit_theme_options',
        'type' => 'option',
        'default' => 1,
        'checked' => 1,
        'sanitize_callback' => 'sanitize_text_field'
    ));

    $wp_customize->add_control('pbr_theme_options[' . $id . ']', array(
        'settings' => 'pbr_theme_options[' . $id . ']',
        'label' => $name_social,
        'section' => $section,
        'type' => 'checkbox',
        'transport' => 4,
    ));
}


add_action('customize_register', 'plant_fnc_blog_settings');
function plant_fnc_blog_settings($wp_customize)
{

    $wp_customize->add_panel('panel_blog', array(
        'priority' => 80,
        'capability' => 'edit_theme_options',
        'theme_supports' => '',
        'title' => esc_html__('Blog & Post', 'plant'),
        'description' => esc_html__('Make default setting for page, general', 'plant'),
    ));


    /**
     * General Setting
     */
    $wp_customize->add_section('blog_general_settings', array(
        'priority' => 10,
        'capability' => 'edit_theme_options',
        'theme_supports' => '',
        'title' => esc_html__('General Setting', 'plant'),
        'description' => '',
        'panel' => 'panel_blog',
    ));


    /**
     * Archive Setting
     */
    $wp_customize->add_section('archive_general_settings', array(
        'priority' => 11,
        'capability' => 'edit_theme_options',
        'theme_supports' => '',
        'title' => esc_html__('Archive & Categgory Setting', 'plant'),
        'description' => '',
        'panel' => 'panel_blog',
    ));
    ///  Archive layout setting
    $wp_customize->add_setting('pbr_theme_options[blog-archive-layout]', array(
        'capability' => 'edit_theme_options',
        'type' => 'option',
        'default' => 'mainright',
        'sanitize_callback' => 'sanitize_text_field'
    ));

    $wp_customize->add_control(new Plant_Layout_DropDown($wp_customize, 'pbr_theme_options[blog-archive-layout]', array(
        'settings' => 'pbr_theme_options[blog-archive-layout]',
        'label' => esc_html__('Archive Layout ', 'plant'),
        'section' => 'archive_general_settings',
        'priority' => 1

    )));

    $wp_customize->add_setting('pbr_theme_options[blog-archive-left-sidebar]', array(
        'capability' => 'edit_theme_options',
        'type' => 'option',
        'default' => 'blog-sidebar-left',
        'sanitize_callback' => 'sanitize_text_field'
    ));


    $wp_customize->add_control(new Plant_Sidebar_DropDown($wp_customize, 'pbr_theme_options[blog-archive-left-sidebar]', array(
        'settings' => 'pbr_theme_options[blog-archive-left-sidebar]',
        'label' => esc_html__('Archive Left Sidebar', 'plant'),
        'section' => 'archive_general_settings',
        'priority' => 2
    )));

    ///
    $wp_customize->add_setting('pbr_theme_options[blog-archive-right-sidebar]', array(
        'capability' => 'edit_theme_options',
        'type' => 'option',
        'default' => 'blog-sidebar-right',
        'sanitize_callback' => 'sanitize_text_field'
    ));

    $wp_customize->add_control(new Plant_Sidebar_DropDown($wp_customize, 'pbr_theme_options[blog-archive-right-sidebar]', array(
        'settings' => 'pbr_theme_options[blog-archive-right-sidebar]',
        'label' => esc_html__('Archive Right Sidebar', 'plant'),
        'section' => 'archive_general_settings',
        'priority' => 2
    )));
    if (class_exists('PbrThemerSetting')):

        $wp_customize->add_setting('pbr_theme_options[archive_headerlayout]', array(
            'type' => 'option',
            'capability' => 'manage_options',
            'default' => '',
            'sanitize_callback' => 'sanitize_text_field'
        ));

        $wp_customize->add_control('pbr_theme_options[archive_headerlayout]', array(
            'label' => esc_html__('Header Layout Style', 'plant'),
            'section' => 'archive_general_settings',
            'type' => 'select',
            'choices' => array('' => 'Default'),
            'choices' => plant_fnc_get_header_layouts(),
        ));
    endif;
    /**
     * Single post Setting
     */
    $wp_customize->add_section('blog_single_settings', array(
        'priority' => 12,
        'capability' => 'edit_theme_options',
        'theme_supports' => '',
        'title' => esc_html__('Single post Setting', 'plant'),
        'description' => '',
        'panel' => 'panel_blog',
    ));


    $wp_customize->add_setting('pbr_theme_options[blog-show-share-post]', array(
        'capability' => 'edit_theme_options',
        'type' => 'option',
        'default' => 0,
        'checked' => 0,
        'sanitize_callback' => 'sanitize_text_field'
    ));

    $wp_customize->add_control('pbr_theme_options[blog-show-share-post]', array(
        'settings' => 'pbr_theme_options[blog-show-share-post]',
        'label' => esc_html__('Show share post', 'plant'),
        'section' => 'blog_single_settings',
        'type' => 'checkbox',
        'transport' => 4,
    ));

    $wp_customize->add_setting('pbr_theme_options[blog-show-related-post]', array(
        'capability' => 'edit_theme_options',
        'type' => 'option',
        'default' => 1,
        'checked' => 1,
        'sanitize_callback' => 'sanitize_text_field'
    ));

    $wp_customize->add_control('pbr_theme_options[blog-show-related-post]', array(
        'settings' => 'pbr_theme_options[blog-show-related-post]',
        'label' => esc_html__('Show related post', 'plant'),
        'section' => 'blog_single_settings',
        'type' => 'checkbox',
        'transport' => 4,
    ));


    $wp_customize->add_setting('pbr_theme_options[blog-items-show]', array(
        'type' => 'option',
        'default' => 4,
        'capability' => 'edit_theme_options',
        'sanitize_callback' => 'sanitize_text_field'
    ));

    $wp_customize->add_control('pbr_theme_options[blog-items-show]', array(
        'label' => esc_html__('Number of related posts to show', 'plant'),
        'section' => 'blog_single_settings',
        'type' => 'select',
        'choices' => array(
            '2' => esc_html__('2 posts', 'plant'),
            '3' => esc_html__('3 posts', 'plant'),
            '4' => esc_html__('4 posts', 'plant'),
            '6' => esc_html__('6 posts', 'plant'),
        )
    ));


    ///  single layout setting
    $wp_customize->add_setting('pbr_theme_options[blog-single-layout]', array(
        'capability' => 'edit_theme_options',
        'type' => 'option',
        'default' => '',
        'sanitize_callback' => 'sanitize_text_field'
    ));

    $wp_customize->add_control(new Plant_Layout_DropDown($wp_customize, 'pbr_theme_options[blog-single-layout]', array(
        'settings' => 'pbr_theme_options[blog-single-layout]',
        'label' => esc_html__('Single Blog Layout', 'plant'),
        'section' => 'blog_single_settings'
    )));


    $wp_customize->add_setting('pbr_theme_options[blog-single-left-sidebar]', array(
        'capability' => 'edit_theme_options',
        'type' => 'option',
        'default' => '',
        'sanitize_callback' => 'sanitize_text_field'
    ));

    $wp_customize->add_control(new Plant_Sidebar_DropDown($wp_customize, 'pbr_theme_options[blog-single-left-sidebar]', array(
        'settings' => 'pbr_theme_options[blog-single-left-sidebar]',
        'label' => esc_html__('Single blog Left Sidebar', 'plant'),
        'section' => 'blog_single_settings'
    )));

    $wp_customize->add_setting('pbr_theme_options[blog-single-right-sidebar]', array(
        'capability' => 'edit_theme_options',
        'type' => 'option',
        'default' => '',
        'sanitize_callback' => 'sanitize_text_field'
    ));

    $wp_customize->add_control(new Plant_Sidebar_DropDown($wp_customize, 'pbr_theme_options[blog-single-right-sidebar]', array(
        'settings' => 'pbr_theme_options[blog-single-right-sidebar]',
        'label' => esc_html__('Single blog Right Sidebar', 'plant'),
        'section' => 'blog_single_settings'
    )));


}


/**
 * Sanitize the Featured Content layout value.
 *
 * @since Plant 1.0
 *
 * @param string $layout Layout type.
 * @return string Filtered layout type (grid|slider).
 */
function plant_fnc_sanitize_layout($layout)
{
    if (!in_array($layout, array('grid', 'slider'))) {
        $layout = 'grid';
    }

    return $layout;
}

/**
 * Bind JS handlers to make Customizer preview reload changes asynchronously.
 *
 * @since Plant 1.0
 */
function plant_fnc_customize_preview_js()
{
    wp_enqueue_script('plant-fnc-customizer', get_template_directory_uri() . '/js/customizer.js', array('customize-preview'), '20131205', true);
}

add_action('customize_preview_init', 'plant_fnc_customize_preview_js');

/**
 * Add contextual help to the Themes and Post edit screens.
 *
 * @since Plant 1.0
 */
function plant_fnc_contextual_help()
{
    if ('admin_head-edit.php' === current_filter() && 'post' !== $GLOBALS['typenow']) {
        return;
    }

    get_current_screen()->add_help_tab(array(
        'id' => 'plant',
        'title' => esc_html__('Plant', 'plant'),
        'content' =>
            '<ul>' .
            '<li>' . sprintf(wp_kses_post(esc_html__('The home page features your choice of up to 6 posts prominently displayed in a grid or slider, controlled by a <a href="%1$s">tag</a>; you can change the tag and layout in <a href="%2$s">Appearance &rarr; Customize</a>. If no posts match the tag, <a href="%3$s">sticky posts</a> will be displayed instead.', 'plant')), esc_url(add_query_arg('tag', _x('featured', 'featured content default tag slug', 'plant'), admin_url('edit.php'))), admin_url('customize.php'), admin_url('edit.php?show_sticky=1')) . '</li>' .
            '<li>' . sprintf(wp_kses_post(esc_html__('Enhance your site design by using <a href="%s">Featured Images</a> for posts you&rsquo;d like to stand out (also known as post thumbnails). This allows you to associate an image with your post without inserting it. Plant uses featured images for posts and pages&mdash;above the title&mdash;and in the Featured Content area on the home page.', 'plant')), 'https://codex.wordpress.org/Post_Thumbnails#Setting_a_Post_Thumbnail') . '</li>' .
            '<li>' . sprintf(wp_kses_post(esc_html__('For an in-depth tutorial, and more tips and tricks, visit the <a href="%s">Plant documentation</a>.', 'plant')), 'http://engotheme.com/guides/plant/') . '</li>' .
            '</ul>',
    ));
}

add_action('admin_head-themes.php', 'plant_fnc_contextual_help');
add_action('admin_head-edit.php', 'plant_fnc_contextual_help');



// Style Block Editor

function plant_block_editor_styles() {
    wp_enqueue_style(
        'slug-block-editor-styles',
        get_theme_file_uri( 'css/editor.css' ),
        false
    );
}

add_action( 'enqueue_block_editor_assets', 'plant_block_editor_styles' );

