<?php

/**
 * Remove javascript and css files not use
 */

/**
 * Hook to select header layout for archive layout
 */
function plant_fnc_get_header_layout($layout = '')
{
    global $post;

    $layout = $post && get_post_meta($post->ID, 'plant_header_layout', 1) ? get_post_meta($post->ID, 'plant_header_layout', 1) : plant_fnc_theme_options('headerlayout');

    if ($layout && $layout != 'global') {
        return trim($layout);
    } elseif ($layout == 'global' && $layout = plant_fnc_theme_options('headerlayout', '')) {
        return trim($layout);
    }

    return $layout;
}

add_filter('plant_fnc_get_header_layout', 'plant_fnc_get_header_layout');

/**
 * Hook to select header layout for archive layout
 */
function plant_fnc_get_footer_profile()
{

    global $post;

    $profile = is_page() && $post ? get_post_meta($post->ID, 'plant_footer_profile', 1) : '';

    if ($profile && $profile != 'global') {
        return trim($profile);
    } elseif ($profile = plant_fnc_theme_options('footer-style', $profile)) {
        return trim($profile);
    }

    return $profile;
}

add_filter('plant_fnc_get_footer_profile', 'plant_fnc_get_footer_profile');


/**
 * Render Custom Css Renderig by Visual composer
 */
if (!function_exists('plant_fnc_print_style_footer')) {
    function plant_fnc_print_style_footer()
    {
        $footer = plant_fnc_get_footer_profile();
        if ($footer != 'default') {
            $shortcodes_custom_css = get_post_meta($footer, '_wpb_shortcodes_custom_css', true);
            if (!empty($shortcodes_custom_css)) {
                echo '<style>
                    ' . $shortcodes_custom_css . '
                    </style>';
            }
        }
    }

    add_action('wp_head', 'plant_fnc_print_style_footer', 18);
}


/**
 * Hook to show breadscrumbs
 */
function plant_fnc_render_breadcrumbs()
{

    global $post;
    $el_class = '';
    $el_style = '';
    if (!is_search()) {
        if (get_post_meta($post->ID, 'plant_stylebreadscrumbs', 1)) {
            $stylebreadscrumb = get_post_meta($post->ID, 'plant_stylebreadscrumbs', 1);
        }
    }
    $stylebreadscrumbs = (!empty($stylebreadscrumb) && isset($stylebreadscrumb)) ? $stylebreadscrumb : '';
    if (is_object($post) && is_page()) {
        $disable = get_post_meta($post->ID, 'plant_disable_breadscrumb', 1);
        if ($disable || is_front_page()) {
            return true;
        }
        $bgimage = get_post_meta($post->ID, 'plant_background_breadscrumbs', 1);
        if (!empty($bgimage)) {
            $bgimage = wp_get_attachment_url($bgimage);
        } else {
            $bgimage = plant_fnc_theme_options('breadcrumb_image', '');
        }


    } elseif (class_exists('WooCommerce') && is_shop()) {
        $bgimage = plant_fnc_theme_options('wc_image_brearumb', '');
    } else {
        $bgimage = plant_fnc_theme_options('breadcrumb_image', '');;
    }
    if (!empty($bgimage) && isset($bgimage)) {
        $el_class .= "has__bgr";
    } else {
        $el_class .= "hasv__bgr container";
    }
    $el_class .= ' ' . $stylebreadscrumbs;
    if (!empty($bgimage)) {
        $el_style .= 'style="background-image: url(' . esc_url($bgimage) . ')"';
    } else {
        $el_style = '';
    }
    if ($stylebreadscrumbs == 'parallax') {
        echo '<div class="breadcrumb ' . esc_html($el_class) . '" ' . trim($el_style) . '>';
        plant_fnc_breadcrumbs();
        echo '</div>';
    } else {
        if (!is_front_page() && !is_home()) {
            echo '<div class="breadcrumb ' . esc_html($el_class) . '">';
            if (!empty($bgimage) && isset($bgimage)): ?>
                <img src="<?php echo esc_url($bgimage); ?>"
                     alt="<?php echo esc_attr(get_bloginfo('name', 'display')); ?>">
            <?php
            endif;
            plant_fnc_breadcrumbs();
            echo '</div>';
        }
    }

}

add_action('plant_template_main_before', 'plant_fnc_render_breadcrumbs');
/**
 * Main Container
 */

function plant_template_main_container_class($class)
{
    global $post;
    global $plant_wpopconfig;

    if (is_object($post)) {
        $layoutcls = get_post_meta($post->ID, 'plant_enable_fullwidth_layout', 1);
        if ($layoutcls) {
            $plant_wpopconfig['layout'] = 'fullwidth';
            return 'container-fluid';
        }
    }

    return $class;
}

add_filter('plant_template_main_container_class', 'plant_template_main_container_class', 1, 1);
add_filter('plant_template_main_content_class', 'plant_template_main_container_class', 1, 1);


function plant_template_footer_before()
{
    return get_sidebar('newsletter');
}

//add_action( 'plant_template_footer_before', 'plant_template_footer_before' );


/**
 * Get Configuration for Page Layout
 *
 */
function plant_fnc_get_page_sidebar_configs($configs = '')
{

    global $post;
    if (is_object($post)) {
        $left = get_post_meta($post->ID, 'plant_leftsidebar', 1);
        $right = get_post_meta($post->ID, 'plant_rightsidebar', 1);
        $layout = get_post_meta($post->ID, 'plant_page_layout', 1);
    } else {
        $left = 1;
        $right = 1;
        $layout = 1;
    }
    return plant_fnc_get_layout_configs($layout, $left, $right, $configs);
}

add_filter('plant_fnc_get_page_sidebar_configs', 'plant_fnc_get_page_sidebar_configs', 1, 1);

//Config page blog sidebar
function plant_fnc_get_page_blog_sidebar_configs($configs = '')
{

    global $post;
    if (is_object($post)) {
        $left = get_post_meta($post->ID, 'plant_leftsidebar', 1);
        $right = get_post_meta($post->ID, 'plant_rightsidebar', 1);
        $layout = get_post_meta($post->ID, 'plant_page_layout', 1);
    } else {
        $left = 1;
        $right = 1;
        $layout = 1;
    }
    return plant_fnc_get_blog_layout_configs($layout, $left, $right, $configs);
}

add_filter('plant_fnc_get_page_blog_sidebar_configs', 'plant_fnc_get_page_blog_sidebar_configs', 1, 1);


function plant_fnc_get_single_sidebar_configs($configs = '')
{

    global $post;

    $layout = plant_fnc_theme_options('blog-single-layout', 'fullwidth');
    $left = plant_fnc_theme_options('blog-single-left-sidebar', 'blog-sidebar-left');
    $right = plant_fnc_theme_options('blog-single-right-sidebar', 'blog-sidebar-right');

    return plant_fnc_get_blog_layout_configs($layout, $left, $right, $configs);
}

add_filter('plant_fnc_get_single_sidebar_configs', 'plant_fnc_get_single_sidebar_configs', 1, 1);

function plant_fnc_get_archive_sidebar_configs($configs = '')
{

    $left = plant_fnc_theme_options('blog-archive-left-sidebar', 'blog-sidebar-left');
    $right = plant_fnc_theme_options('blog-archive-right-sidebar', 'blog-sidebar-right');
    $layout = plant_fnc_theme_options('blog-archive-layout', 'fullwidth');

    return plant_fnc_get_blog_layout_configs($layout, $left, $right, $configs);
}

add_filter('plant_fnc_get_archive_sidebar_configs', 'plant_fnc_get_archive_sidebar_configs', 1, 1);
add_filter('plant_fnc_get_category_sidebar_configs', 'plant_fnc_get_archive_sidebar_configs', 1, 1);


function plant_fnc_sidebars_others_configs()
{

    global $plant_page_layouts;

    return $plant_page_layouts;
}

add_filter("plant_fnc_sidebars_others_configs", "plant_fnc_sidebars_others_configs");


function plant_fnc_get_layout_configs($layout, $left, $right, $configs = array())
{

    switch ($layout) {


        //One Sidebar Right
        case 'mainright':
            $configs['sidebars'] = array(
                'left' => array('show' => false),
                'right' => array(
                    'show' => true,
                    'sidebar' => $right,
                    'active' => is_active_sidebar($right),
                    'class' => 'col-xs-12 col-md-3'
                )
            );
            $configs['main'] = array('class' => 'col-xs-12 col-md-9 pull-left');
            break;

        // One Sidebar Left
        case 'leftmain':
            $configs['sidebars'] = array(
                'left' => array(
                    'show' => true,
                    'sidebar' => $left,
                    'active' => is_active_sidebar($left),
                    'class' => 'col-xs-12 col-md-3'
                ),
                'right' => array('show' => false)
            );
            $configs['main'] = array('class' => 'col-xs-12 col-md-9 pull-right');
            break;

        // Fullwidth
        default:
            $configs['sidebars'] = array(
                'left' => array('show' => false),
                'right' => array('show' => false)
            );
            $configs['main'] = array('class' => 'col-xs-12 col-md-12');
            break;
    }

    return $configs;
}

function plant_fnc_get_blog_layout_configs($layout, $left, $right, $configs = array())
{

    switch ($layout) {
        //One Sidebar Right
        case 'mainright':
            $configs['sidebars'] = array(
                'left' => array('show' => false),
                'right' => array(
                    'show' => true,
                    'sidebar' => $right,
                    'active' => is_active_sidebar($right),
                    'class' => 'col-xs-12 col-md-4 col-lg-3 pull-right'
                )
            );
            $configs['main'] = array('class' => 'col-xs-12 col-md-8 col-lg-9 pull-left');
            break;

        // One Sidebar Left
        case 'leftmain':
            $configs['sidebars'] = array(
                'left' => array(
                    'show' => true,
                    'sidebar' => $left,
                    'active' => is_active_sidebar($left),
                    'class' => 'col-xs-12 col-md-3'
                ),
                'right' => array('show' => false)
            );
            $configs['main'] = array('class' => 'col-xs-12 col-md-9 pull-right');
            break;

        // Fullwidth
        default:
            $configs['sidebars'] = array(
                'left' => array('show' => false),
                'right' => array('show' => false)
            );
            $configs['main'] = array('class' => 'col-xs-12 col-md-12');
            break;
    }

    return $configs;

}

if (!function_exists('plant_fnc_related_post')) {
    function plant_fnc_related_post($relate_count = 4, $posttype = 'post', $taxonomy = 'category')
    {

        $terms = get_the_terms(get_the_ID(), $taxonomy);
        $termids = array();

        if ($terms) {
            foreach ($terms as $term) {
                $termids[] = $term->term_id;
            }
        }

        $args = array(
            'post_type' => $posttype,
            'posts_per_page' => $relate_count,
            'post__not_in' => array(get_the_ID()),
            'tax_query' => array(
                'relation' => 'AND',
                array(
                    'taxonomy' => $taxonomy,
                    'field' => 'id',
                    'terms' => $termids,
                    'operator' => 'IN'
                )
            )
        );


        $relates = new WP_Query($args);
        if ($relates->have_posts()): ?>
            <div class="widget">
                <h4 class="related-post-title">
                    <span><?php esc_html_e('Related post', 'plant'); ?></span>
                </h4>

                <div class="related-posts-content">
                    <div class="row">
                        <?php
                        $class_column = 12 / $relate_count;
                        while ($relates->have_posts()) : $relates->the_post();
                            ?>
                            <div class="col-sm-<?php echo esc_attr($class_column); ?> col-md-<?php echo esc_attr($class_column); ?> col-lg-<?php echo esc_attr($class_column); ?>">
                                <article class="post">
                                    <?php
                                    if (has_post_thumbnail()) {
                                        ?>
                                        <figure class="entry-thumb">
                                            <a href="<?php the_permalink(); ?>" class="entry-image zoom-2">
                                                <?php the_post_thumbnail(); ?>
                                            </a>
                                            <!-- vote    -->
                                            <?php do_action('plant_fnc_rating') ?>
                                        </figure>
                                        <?php
                                    }
                                    ?>
                                    <div class="entry-content">

                                        <?php if (get_the_title()) { ?>
                                            <h4 class="entry-title">
                                                <a href="<?php the_permalink(); ?>"><?php the_title(); ?></a>
                                            </h4>
                                        <?php } ?>
                                        <div class="entry-meta clearfix">
                                    <span class="entry-date">
                                    <span><?php echo get_the_date(get_option('date_time')); ?>
                                    </span>
                                            <span class="meta-sep"> | </span>
                                            <span class="author"><?php esc_html_e('by ', 'plant');
                                                the_author_posts_link(); ?></span>
                                            <span class="meta-sep"> | </span>
                                        <?php if (!post_password_required() && (comments_open() || get_comments_number())) : ?>
                                            <span class="comments-link"><span
                                                        class="fa fa-comment-o"></span> <?php comments_popup_link(esc_html__('Leave a comment', 'plant'), esc_html__('1 Comment', 'plant'), esc_html__('% Comments', 'plant')); ?></span>
                                        <?php endif; ?>
                                        </div>

                                    </div>
                                </article>
                            </div>
                        <?php
                        endwhile; ?>
                    </div>
                </div>

            </div>
        <?php
        endif;
        wp_reset_postdata();
    }
}


/**
 * Custom template tags for Plant
 *
 * @package ENGOTHEME
 * @subpackage Plant
 * @since Plant 1.0
 */

if (!function_exists('plant_fnc_paging_nav')) :
    /**
     * Display navigation to next/previous set of posts when applicable.
     *
     * @since Plant 1.0
     *
     * @global WP_Query $wp_query WordPress Query object.
     * @global WP_Rewrite $wp_rewrite WordPress Rewrite object.
     */
    function plant_fnc_paging_nav()
    {
        global $wp_query, $wp_rewrite;

        // Don't print empty markup if there's only one page.
        if ($wp_query->max_num_pages < 2) {
            return;
        }

        $paged = get_query_var('paged') ? intval(get_query_var('paged')) : 1;
        $pagenum_link = html_entity_decode(get_pagenum_link());
        $query_args = array();
        $url_parts = explode('?', $pagenum_link);

        if (isset($url_parts[1])) {
            wp_parse_str($url_parts[1], $query_args);
        }

        $pagenum_link = remove_query_arg(array_keys($query_args), $pagenum_link);
        $pagenum_link = trailingslashit($pagenum_link) . '%_%';

        $format = $wp_rewrite->using_index_permalinks() && !strpos($pagenum_link, 'index.php') ? 'index.php/' : '';
        $format .= $wp_rewrite->using_permalinks() ? user_trailingslashit($wp_rewrite->pagination_base . '/%#%', 'paged') : '?paged=%#%';

        // Set up paginated links.
        $links = paginate_links(array(
            'base' => $pagenum_link,
            'format' => $format,
            'total' => $wp_query->max_num_pages,
            'current' => $paged,
            'mid_size' => 1,
            'add_args' => array_map('urlencode', $query_args),
            'prev_text' => esc_html__('Previous', 'plant'),
            'next_text' => esc_html__('Next', 'plant'),
        ));

        if ($links) :

            ?>
            <nav class="navigation paging-navigation">
                <h1 class="screen-reader-text"><?php esc_html_e('Posts navigation', 'plant'); ?></h1>
                <div class="pagination loop-pagination">
                    <?php echo trim($links); ?>
                </div><!-- .pagination -->
            </nav><!-- .navigation -->
        <?php
        endif;
    }
endif;

if (!function_exists('plant_fnc_post_nav')) :
    /**
     * Display navigation to next/previous post when applicable.
     *
     * @since Plant 1.0
     */
    function plant_fnc_post_nav()
    {
        // Don't print empty markup if there's nowhere to navigate.
        $previous = (is_attachment()) ? get_post(get_post()->post_parent) : get_adjacent_post(false, '', true);
        $next = get_adjacent_post(false, '', false);

        if (!$next && !$previous) {
            return;
        }

        ?>
        <nav class="navigation post-navigation">
            <h3 class="screen-reader-text"><?php esc_html_e('Post navigation', 'plant'); ?></h3>
            <div class="nav-links clearfix">
                <?php
                if (is_attachment()) :
                    previous_post_link('%link', '<div class="col-lg-6"><span class="meta-nav">' . esc_html__('Published In', 'plant') . '</span></div>');
                else :
                    previous_post_link('%link', '<span class="meta-nav prev">' . esc_html__('Previous Post', 'plant') . '</span>');
                    next_post_link('%link', '<span class="meta-nav next">' . esc_html__('Next Post', 'plant') . '</span>');
                endif;
                ?>
            </div><!-- .nav-links -->
        </nav><!-- .navigation -->
        <?php
    }
endif;

if (!function_exists('plant_fnc_posted_on')) :
    /**
     * Print HTML with meta information for the current post-date/time and author.
     *
     * @since Plant 1.0
     */
    function plant_fnc_posted_on()
    {
        if (is_sticky() && is_home() && !is_paged()) {
            echo '<span class="featured-post"><span class="fa fa-clock-o"></span> ' . esc_html__('Sticky', 'plant') . '</span>';
        }

        // Set up and print post meta information.
        printf('<span class="entry-date"><span class="fa fa-clock-o"></span> <a href="%1$s" rel="bookmark"><time class="entry-date" datetime="%2$s">%3$s</time></a></span> <span class="byline"><span class="author vcard"><a class="url fn n" href="%4$s" rel="author">%5$s</a></span></span>',
            esc_url(get_permalink()),
            esc_attr(get_the_date('c')),
            esc_html(get_the_date()),
            esc_url(get_author_posts_url(get_the_author_meta('ID'))),
            get_the_author()
        );
    }
endif;

/**
 * Find out if blog has more than one category.
 *
 * @return boolean true if blog has more than 1 category
 * @since Plant 1.0
 *
 */
function plant_fnc_categorized_blog()
{
    if (false === ($all_the_cool_cats = get_transient('plant_fnc_category_count'))) {
        // Create an array of all the categories that are attached to posts
        $all_the_cool_cats = get_categories(array(
            'hide_empty' => 1,
        ));

        // Count the number of categories that are attached to the posts
        $all_the_cool_cats = count($all_the_cool_cats);

        set_transient('plant_fnc_category_count', $all_the_cool_cats);
    }

    if (1 !== (int)$all_the_cool_cats) {
        // This blog has more than 1 category so plant_fnc_categorized_blog should return true
        return true;
    } else {
        // This blog has only 1 category so plant_fnc_categorized_blog should return false
        return false;
    }
}

/**
 * Flush out the transients used in plant_fnc_categorized_blog.
 *
 * @since Plant 1.0
 */
function plant_fnc_category_transient_flusher()
{
    // Like, beat it. Dig?
    delete_transient('plant_fnc_category_count');
}

add_action('edit_category', 'plant_fnc_category_transient_flusher');
add_action('save_post', 'plant_fnc_category_transient_flusher');

if (!function_exists('plant_fnc_post_thumbnail')) :
    /**
     * Display an optional post thumbnail.
     *
     * Wraps the post thumbnail in an anchor element on index
     * views, or a div element when on single views.
     *
     * @since Plant 1.0
     * @since Plant 1.4 Was made 'pluggable', or overridable.
     */
    function plant_fnc_post_thumbnail()
    {
        if (post_password_required() || is_attachment() || !has_post_thumbnail()) {
            return;
        }

        if (is_singular()) :
            ?>

            <div class="post-thumbnail">
                <?php
                if ((!is_active_sidebar('sidebar-2') || is_page_template('page-templates/full-width.php'))) {
                    the_post_thumbnail('plant-full-width');
                } else {
                    the_post_thumbnail();
                }
                ?>
            </div>

        <?php else : ?>

            <a class="post-thumbnail" href="<?php the_permalink(); ?>" aria-hidden="true">
                <?php
                if ((!is_active_sidebar('sidebar-2') || is_page_template('page-templates/full-width.php'))) {
                    the_post_thumbnail('plant-full-width');
                } else {
                    the_post_thumbnail('post-thumbnail', array('alt' => get_the_title()));
                }
                ?>
            </a>

        <?php endif; // End is_singular()
    }
endif;

if (!function_exists('plant_fnc_excerpt_more') && !is_admin()) :
    /**
     * Replaces "[...]" (appended to automatically generated excerpts) with ...
     * and a Continue reading link.
     *
     * @param string $more Default Read More excerpt link.
     * @return string Filtered Read More excerpt link.
     * @since Plant 1.3
     *
     */
    function plant_fnc_excerpt_more($more)
    {
        $link = sprintf('<a href="%1$s" class="more-link">%2$s</a>',
            esc_url(get_permalink(get_the_ID())),
            /* translators: %s: Name of current post */
            sprintf(esc_html__('Continue reading %s', 'plant'), '<span class="screen-reader-text">' . get_the_title(get_the_ID()) . '</span>') . ' <span class="meta-nav">&rarr;</span>'
        );
        return ' &hellip; ' . $link;
    }

    add_filter('excerpt_more', 'plant_fnc_excerpt_more');
endif;

/**
 * Extend the default WordPress body classes.
 *
 * Adds body classes to denote:
 * 1. Single or multiple authors.
 * 2. Presence of header image except in Multisite signup and activate pages.
 * 3. Index views.
 * 4. Full-width content layout.
 * 5. Presence of footer widgets.
 * 6. Single views.
 * 7. Featured content layout.
 *
 * @param array $classes A list of existing body class values.
 * @return array The filtered body class list.
 * @since Plant 1.0
 *
 */
function plant_fnc_body_classes($classes)
{
    global $post;

    $additionclass = (is_object($post) ? get_post_meta($post->ID, 'plant_additionclass', 1) : '');
    if (!empty($additionclass)) {
        $classes[] = $additionclass;
    }

    if (is_multi_author()) {
        $classes[] = 'group-blog';
    }

    if (get_header_image()) {
        $classes[] = 'header-image';
    } elseif (!in_array($GLOBALS['pagenow'], array('wp-activate.php', 'wp-signup.php'))) {
        $classes[] = 'masthead-fixed';
    }


    if (is_singular() && !is_front_page()) {
        $classes[] = 'singular';
    }

    $currentSkin = str_replace('.css', '', plant_fnc_theme_options('skin', 'default'));

    if ($currentSkin) {
        $class[] = 'skin-' . $currentSkin;
    }

    return $classes;
}

add_filter('body_class', 'plant_fnc_body_classes');

/**
 * Create a nicely formatted and more specific title element text for output
 * in head of document, based on current view.
 *
 * @param string $title Default title text for current view.
 * @param string $sep Optional separator.
 * @return string The filtered title.
 * @since Plant 1.0
 *
 * @global int $paged WordPress archive pagination page count.
 * @global int $page WordPress paginated post page count.
 *
 */
function plant_fnc_wp_title($title, $sep)
{
    global $paged, $page;

    if (is_feed()) {
        return $title;
    }

    // Add the site name.
    $title .= get_bloginfo('name', 'display');

    // Add the site description for the home/front page.
    $site_description = get_bloginfo('description', 'display');
    if ($site_description && (is_home() || is_front_page())) {
        $title = "$title $sep $site_description";
    }

    // Add a page number if necessary.
    if (($paged >= 2 || $page >= 2) && !is_404()) {
        $title = "$title $sep " . sprintf(esc_html__('Page %s', 'plant'), max($paged, $page));
    }

    return $title;
}

add_filter('wp_title', 'plant_fnc_wp_title', 10, 2);


/**
 * plant_fnc_breadcrumbs function.
 * Edit the standart breadcrumbs to fit the bootstrap style without producing more css
 * @access public
 * @return void
 */
function plant_fnc_breadcrumbs()
{
    $style = '';
    $color = get_post_meta(get_the_ID(), 'plant_color_breadscrumb', 1);
    if (class_exists('WooCommerce') && is_shop()) {
        $color = plant_fnc_theme_options('vc_link_color', '');
    }
    if ($color) {
        $style .= 'color:' . $color . '';
    } else {
        $style .= '';
    }

    $delimiter = '';
    $home = esc_html__('Home', 'plant');
    $before = '<li>';
    $after = '</li>';
    $title = '';
    $str = '';
    if (!is_home() && !is_front_page() || is_paged()) {

        $str .= '<ul class="clearfix" style="' . $style . '">';

        global $post;
        $homeLink = esc_url(home_url());
        $str .= '<li><a style="' . $style . '" href="' . ($homeLink) . '">' . $home . '</a> ' . $delimiter . '</li> ';

        if (is_category()) {

            global $wp_query;
            $cat_obj = $wp_query->get_queried_object();
            $thisCat = $cat_obj->term_id;
            $thisCat = get_category($thisCat);
            $parentCat = get_category($thisCat->parent);
            if ($thisCat->parent != 0) $str .= (get_category_parents($parentCat, true, ' ' . $delimiter . ' '));
            $str .= trim($before) . single_cat_title('', false) . $after;
            $title = esc_html__('Blog', 'plant');
        } elseif (is_day()) {
            $str .= '<li><a style="' . $style . '" href="' . esc_url(get_year_link(get_the_time('Y'))) . '">' . get_the_time('Y') . '</a></li> ' . $delimiter . ' ';
            $str .= '<li><a style="' . $style . '" href="' . esc_url(get_month_link(get_the_time('Y'), get_the_time('m'))) . '">' . get_the_time('F') . '</a></li> ' . $delimiter . ' ';
            $str .= trim($before) . get_the_time('d') . $after;
            $title = get_the_time('d');
        } elseif (is_month()) {
            $str .= '<li><a style="' . $style . '" href="' . esc_url(get_year_link(get_the_time('Y'))) . '">' . get_the_time('Y') . '</a></li> ' . $delimiter . ' ';
            $str .= trim($before) . get_the_time('F') . $after;
            $title = get_the_time('F');
        } elseif (is_year()) {
            $str .= trim($before) . get_the_time('Y') . $after;
            $title = get_the_time('Y');
        } elseif (is_single() && !is_attachment()) {
            if (get_post_type() == 'product') {
                $product = wc_get_product();
                $terms = get_the_terms($product->get_id(), 'product_cat');
                foreach ($terms as $key => $term) {
                    $str .= '<li><a style="' . $style . '" href="' . esc_url(get_term_link($term->term_id)) . '">' . $term->name . '</a></li> ' . $delimiter . ' ';
                }
                $str .= trim($before) . get_the_title() . $after;
                $title = get_post_type();
            } else {
                $cat = get_the_category();

                $cat = $cat[0];
                $str .= get_category_parents($cat, true, ' ' . $delimiter . ' ');
                $str .= trim($before) . get_the_title() . $after;
                $title = esc_html__('Blog detail', 'plant');
            }

        } elseif (is_attachment()) {
            $parent = get_post($post->post_parent);
            $cat = get_the_category($parent->ID);
            $cat = $cat[0];
            $str .= get_category_parents($cat, true, ' ' . $delimiter . ' ');
            $str .= '<li><a style="' . $style . '" href="' . esc_url(get_permalink($parent)) . '">' . $parent->post_title . '</a></li> ' . $delimiter . ' ';
            $str .= trim($before) . get_the_title() . $after;
            $title = get_the_title();
        } elseif (is_page() && !$post->post_parent) {
            $str .= trim($before) . get_the_title() . $after;
            $title = get_the_title();

        } elseif (is_page() && $post->post_parent) {
            $parent_id = $post->post_parent;
            $breadcrumbs = array();
            while ($parent_id) {
                $page = get_page($parent_id);
                $breadcrumbs[] = '<li><a style="' . $style . '" href="' . esc_url(get_permalink($page->ID)) . '">' . get_the_title($page->ID) . '</a></li>';
                $parent_id = $page->post_parent;
            }
            $breadcrumbs = array_reverse($breadcrumbs);
            foreach ($breadcrumbs as $crumb) $str .= trim($crumb) . ' ' . $delimiter . ' ';
            $str .= trim($before) . get_the_title() . $after;
            $title = get_the_title();
        } elseif (is_search()) {
            $str .= trim($before) . esc_html__('Search results for "', 'plant') . get_search_query() . '"' . $after;
            $title = esc_html__('Search results for "', 'plant') . get_search_query();
        } elseif (is_tag()) {
            $str .= trim($before) . esc_html__('Posts tagged "', 'plant') . single_tag_title('', false) . '"' . $after;
            $title = esc_html__('Posts tagged "', 'plant') . single_tag_title('', false) . '"';
        } elseif (is_author()) {
            global $author;
            $userdata = get_userdata($author);
            $str .= trim($before) . esc_html__('Articles posted by ', 'plant') . $userdata->display_name . $after;
            $title = esc_html__('Articles posted by ', 'plant') . $userdata->display_name;
        } elseif (is_404()) {
            $str .= trim($before) . esc_html__('Error 404', 'plant') . $after;
            $title = esc_html__('Error 404', 'plant');
        } elseif (!is_single() && !is_page() && get_post_type() != 'post' && !is_404()) {
            $post_type = get_post_type_object(get_post_type());
            if (is_object($post_type)) {
                if (class_exists('WooCommerce') && is_shop()) {
                    $title = esc_html__(' All Products', 'plant');
                    $str .= trim($before) . esc_html__(' All Products', 'plant') . $after;
                } else {
                    $title = $post_type->labels->singular_name;
                    $str .= trim($before) . $post_type->labels->singular_name . $after;
                }
            }
        }
        $str .= '</ul>';

        ?>
        <div class="content-inner clearfix col-xs-12">
            <div class="title" style='<?php echo esc_html($style); ?>'>
                <?php echo esc_html($title); ?>
            </div>
            <div class="ul-breadcrumbs">
                <?php echo trim($str); ?>
            </div>
        </div>
        <?php
    }
}


/**
 *
 */
function plant_display_footer_content()
{
    $footer_profile = apply_filters('plant_fnc_get_footer_profile', 'default');


    if ($footer_profile && !$footer_profile != 'default'):
        $footer_data = plant_fnc_get_footer_profile_postdata($footer_profile);
        ?>
        <?php if ($footer_data): ?>
        <div class="opal-footer-profile clearfix">
            <?php echo do_shortcode($footer_data->post_content);; ?>
        </div>
    <?php endif; ?>
    <?php else: ?>
        <?php get_sidebar('footer'); ?>
    <?php endif; ?>

    <?php
}

/**
 *
 */
function plant_display_footer_copyright()
{
    $copyright_text = plant_fnc_theme_options('copyright_text', '');
    if (!empty($copyright_text)) {
        printf('%s', do_shortcode($copyright_text));
    } else {
        $devby = '<a target="_blank" href="' . esc_url('http://wwww.engotheme.com') . '">' . esc_html__('EngoTheme', 'plant') . '</a>';
        printf(esc_html__('Proudly powered by %s. Developed by %s', 'plant'), 'WordPress', $devby);
    }
}


if (!function_exists('plant_fnc_categories_searchform')) {
    function plant_fnc_categories_searchform()
    {
        if (class_exists('WooCommerce')) {
            $dropdown_args = array(
                'show_counts' => false,
                'hierarchical' => true,
                'show_uncategorized' => 0
            );
            ?>
            <form method="get" class="input-group search-category" action="<?php echo esc_url(home_url('/')); ?>">
                <div class="input-group-addon search-category-container">
                    <div class="select">
                        <?php wc_product_dropdown_categories($dropdown_args); ?>
                    </div>
                </div>
                <input name="s" maxlength="60" class="form-control search-category-input" type="text" size="20"
                       placeholder="<?php esc_attr_e('What do you need...', 'plant'); ?>">

                <div class="input-group-btn">
                    <label class="btn btn-link btn-search">
                        <span class="title-search hidden"><?php esc_html_e('Search', 'plant') ?></span>
                        <input type="submit" class="fa searchsubmit" value="&#xf002;"/>
                    </label>
                    <input type="hidden" name="post_type" value="product"/>
                </div>
            </form>
            <?php
        } else {
            get_search_form();
        }
    }
}


if (!function_exists('plant_pbr_string_limit_words')) {
    function plant_pbr_string_limit_words($string, $word_limit)
    {
        $words = explode(' ', $string, ($word_limit + 1));

        if (count($words) > $word_limit) {
            array_pop($words);
        }

        return implode(' ', $words);
    }
}
if (!function_exists('plant_scrape_instagram')) {
    function plant_scrape_instagram($username, $slice = 9)
    {
        $username = strtolower($username);
        if (false === ($instagram = get_transient('instagram-media-new-' . sanitize_title_with_dashes($username)))) {
            $remote = wp_remote_get('http://instagram.com/' . trim($username));
            if (is_wp_error($remote)) {
                return new WP_Error('site_down', esc_html__('Unable to communicate with Instagram.', 'plant'));
            }
            if (200 != wp_remote_retrieve_response_code($remote)) {
                return new WP_Error('invalid_response', esc_html__('Instagram did not return a 200.', 'plant'));
            }
            $shards = explode('window._sharedData = ', $remote['body']);
            $insta_json = explode(';</script>', $shards[1]);
            $insta_array = json_decode($insta_json[0], true);
            if (!$insta_array) {
                return new WP_Error('bad_json', esc_html__('Instagram has returned invalid data.', 'plant'));
            }
            // old style
            if (isset($insta_array['entry_data']['UserProfile'][0]['userMedia'])) {
                $images = $insta_array['entry_data']['UserProfile'][0]['userMedia'];
                $type = 'old';
                // new style
            } else if (isset($insta_array['entry_data']['ProfilePage'][0]['graphql']['user']['edge_owner_to_timeline_media']['edges'])) {
                $images = $insta_array['entry_data']['ProfilePage'][0]['graphql']['user']['edge_owner_to_timeline_media']['edges'];
                $type = 'new';
            } else {
                return new WP_Error('bad_josn_2', esc_html__('Instagram has returned invalid data.', 'plant'));
            }
            if (!is_array($images)) {
                return new WP_Error('bad_array', esc_html__('Instagram has returned invalid data.', 'plant'));
            }
            $instagram = array();

            switch ($type) {
                case 'old':
                    foreach ($images as $image) {
                        if ($image['user']['username'] == $username) {
                            $image['link'] = preg_replace("/^http:/i", "", $image['link']);
                            $image['images']['thumbnail'] = preg_replace("/^http:/i", "", $image['images']['thumbnail']);
                            $image['images']['standard_resolution'] = preg_replace("/^http:/i", "", $image['images']['standard_resolution']);
                            $image['images']['low_resolution'] = preg_replace("/^http:/i", "", $image['images']['low_resolution']);
                            $instagram[] = array(
                                'description' => $image['caption']['text'],
                                'link' => $image['link'],
                                'time' => $image['created_time'],
                                'comments' => $image['comments']['count'],
                                'likes' => $image['likes']['count'],
                                'thumbnail' => $image['images']['thumbnail'],
                                'large' => $image['images']['standard_resolution'],
                                'small' => $image['images']['low_resolution'],
                                'type' => $image['type'],
                            );
                        }
                    }
                    break;
                default:
                    foreach ($images as $image) {
                        $image['display_src'] = preg_replace("/^http:/", "", $image['node']['thumbnail_src']);
                        if ($image['node']['is_video'] == true) {
                            $type = 'video';
                        } else {
                            $type = 'image';
                        }
                        $instagram[] = array(
                            'description' => esc_html__('Instagram Image', 'plant'),
                            'link' => '//instagram.com/p/' . $image['node']['shortcode'],
                            'time' => $image['node']['taken_at_timestamp'],
                            'comments' => $image['node']['edge_media_to_comment']['count'],
                            'likes' => $image['node']['edge_media_preview_like']['count'],
                            'thumbnail' => $image['node']['thumbnail_src'],
                            'type' => $type
                        );
                    }
                    break;
            }

            // do not set an empty transient - should help catch private or empty accounts
            if (!empty($instagram)) {

                $instagram = serialize($instagram);
                // HOUR_IN_SECONDS
                set_transient('instagram-media-new-' . sanitize_title_with_dashes($username), $instagram, apply_filters('null_instagram_cache_time', 10));
            }
        }
        if (!empty($instagram)) {
            $instagram = unserialize($instagram);
            return array_slice($instagram, 0, $slice);
        } else {
            return new WP_Error('no_images', esc_html__('Instagram did not return any images.', 'plant'));
        }
    }
}

add_action('wp_ajax_plant_load_more_posts', 'plant_load_more_posts');
add_action('wp_ajax_nopriv_plant_load_more_posts', 'plant_load_more_posts');
function plant_load_more_posts()
{
    $paged = $_POST['paged'];
    $display = $_POST['display'];
    $limit = $_POST['limit'];
    $args = array(
        'post_type' => 'post',
        'posts_per_page' => $limit,
        'paged' => $paged
    );

    $loop = new WP_Query($args);

    ?>

    <?php if ($loop->have_posts()):
    ob_start();
    $i = 0;
    while ($loop->have_posts()) : $loop->the_post();
        $i++;
        $thumbsize = isset($thumbsize) ? $thumbsize : 'thumbnail';
        if ($display == 'masony'):
            ?>
            <div class="item-isotope">
                <div class="wrap-blog">
                    <?php
                    if (has_post_thumbnail()) {
                        ?>
                        <div class="box-img">
                            <a href="<?php echo esc_url(get_the_permalink()); ?>"
                               class="lightbox">
                                <?php the_post_thumbnail($thumbsize); ?>
                            </a>
                        </div>
                        <?php
                    }
                    ?>
                    <div class="entry-content">
                        <div class="entry-between">
                            <?php if (in_array('category', get_object_taxonomies(get_post_type())) && plant_fnc_categorized_blog()) : ?>
                                <span class="label">
                                            <?php echo get_the_category_list(_x(' ', 'Used between list items, there is a space after the comma.', 'plant')); ?>
                                        </span>
                            <?php endif; ?>
                            <span class="comment"><?php comments_popup_link(esc_html__('0', 'plant'), esc_html__(' 1', 'plant'), esc_html__('%', 'plant')); ?></span>
                        </div>
                        <div class="entry-meta">
                            <div class="entry-date">
                                <p class="date"><?php echo get_the_date(get_option('date_time')); ?></p>
                            </div>
                            <div class="entry-title">
                                <a href="<?php echo esc_url(get_the_permalink()); ?>"><?php the_title(); ?></a>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
        <?php else: ?>
            <div class="item-zigzag clearfix">
                <div class="row">
                    <?php if (has_post_thumbnail()) { ?>
                        <div class="col-sm-6 col-xs-12 <?php if ($i % 2 !== 0) {
                            echo esc_attr('col-sm-push-6');
                        } ?>">

                            <div class="post-standard">
                                <a href="<?php echo esc_url(get_the_permalink()); ?>">
                                    <figure><?php the_post_thumbnail('full'); ?></figure>
                                </a>
                            </div>
                        </div>
                        <?php
                    }
                    ?>
                    <div class="<?php if (has_post_thumbnail()): ?> col-sm-6 col-xs-12 feature-content <?php if ($i % 2 !== 0) {
                        echo esc_attr('col-sm-pull-6');
                    } ?> <?php else: ?> col-xs-12 feature-content <?php endif; ?>">
                        <div class="oct_top_featured_content">
                            <span class="oct_day"><?php echo get_the_date(get_option('date_time')); ?></span>
                        </div>
                        <h3 class="oct_blog_title"><?php if (is_sticky()): ?><i
                                    class="fa fa-sticky-note"></i><?php endif; ?><a
                                    href="<?php echo esc_url(get_the_permalink()); ?>"><?php echo get_the_title(); ?></a>
                        </h3>
                        <?php if (!empty(get_the_excerpt())): ?>
                            <p class="k_blog_content"><?php echo get_the_excerpt(); ?></p>
                        <?php endif; ?>
                        <a class="btn-web "
                           href="<?php echo esc_url(get_the_permalink()); ?>"><?php echo esc_html__('Read More', 'plant'); ?></a>
                    </div>
                </div>
            </div>
        <?php endif; ?>
    <?php endwhile; endif; ?>
    <?php

    $posts = ob_get_clean();
    $result['posts'] = $posts;
    print_r(json_encode($result));
    wp_reset_postdata();
    exit();
}