<?php 
if( class_exists("WPBakeryShortCode") ){
	/**
	 * Class Plant_VC_Woocommerces
	 *
	 */
	class Plant_VC_Woocommerce  implements Vc_Vendor_Interface  {

		/**
		 * register and mapping shortcodes
		 */
		public function product_category_field_search( $search_string ) {
			$data = array();
			$vc_taxonomies_types = array('product_cat');
			$vc_taxonomies = get_terms( $vc_taxonomies_types, array(
				'hide_empty' => false,
				'search' => $search_string
			) );
			if ( is_array( $vc_taxonomies ) && ! empty( $vc_taxonomies ) ) {
				foreach ( $vc_taxonomies as $t ) {
					if ( is_object( $t ) ) {
						$data[] = vc_get_term_object( $t );
					}
				}
			}
			return $data;
		}

		public function product_category_render($query) {  
			$category = get_term_by('id', (int)$query['value'], 'product_cat');
			if ( ! empty( $query ) && !empty($category)) {
				$data = array();
				$data['value'] = $category->term_id;
				$data['label'] = $category->name;
				return ! empty( $data ) ? $data : false;
			}
			return false;
		}

		/**
		 * register and mapping shortcodes
		 */
		public function load(){  

			$shortcodes = array( 'pbr_products', 'pbr_products_collection', 'pbr_product_categories_tab' ); 

			foreach( $shortcodes as $shortcode ){
				add_filter( 'vc_autocomplete_'. $shortcode .'_categories_callback', array($this, 'product_category_field_search'), 10, 1 );
			 	add_filter( 'vc_autocomplete_'. $shortcode .'_categories_render', array($this, 'product_category_render'), 10, 1 );
			}


			$order_by_values = array(
				'',
				esc_html__( 'Date', 'plant' ) => 'date',
				esc_html__( 'ID', 'plant' ) => 'ID',
				esc_html__( 'Author', 'plant' ) => 'author',
				esc_html__( 'Title', 'plant' ) => 'title',
				esc_html__( 'Modified', 'plant' ) => 'modified',
				esc_html__( 'Random', 'plant' ) => 'rand',
				esc_html__( 'Comment count', 'plant' ) => 'comment_count',
				esc_html__( 'Menu order', 'plant' ) => 'menu_order',
			);

			$options = array(    
                esc_html__( 'Latest Product', 'plant' ) 		=> 'recent_products',
                esc_html__( 'Sale Product', 'plant' )   		=> 'sale_products',
                esc_html__( 'Featured Product', 'plant' ) 		=> 'featured_products',
                esc_html__( 'Best Selling', 'plant' ) 			=> 'best_selling_products',
                esc_html__( 'Top Rate', 'plant' ) 				=> 'top_rate',
            ); 

			$order_way_values = array(
				'',
				esc_html__( 'Descending', 'plant' ) => 'DESC',
				esc_html__( 'Ascending', 'plant' ) => 'ASC',
			);
			$product_categories_dropdown = array(''=> esc_html__('None', 'plant') );
			$block_styles = plant_fnc_get_widget_block_styles();
			
			$product_columns_deal = array(1, 2, 3, 4);

			if( is_admin() ){
					$args = array(
						'type' => 'post',
						'child_of' => 0,
						'parent' => '',
						'orderby' => 'name',
						'order' => 'ASC',
						'hide_empty' => false,
						'hierarchical' => 1,
						'exclude' => '',
						'number' => '',
						'taxonomy' => 'product_cat',
						'pad_counts' => false,

					);

					$categories = get_categories( $args );
					plant_fnc_woocommerce_getcategorychilds( 0, $categories, 0, $product_categories_dropdown );
					
			}
		  
			/**
			 * pbr_productcategory
			 */
		 
			$sidebar_product_lists = [
				esc_html__('None', 'plant') => 'none',
				esc_html__('New Arrives', 'plant') => 'recent_product',
				esc_html__('Special Products', 'plant') => 'on_sale'
			];
			$product_layout = array('Grid'=>'grid','List'=>'list','Carousel Default'=>'carousel', 'Carousel Special'=>'special','Carousel Special v2'=>'special-v2');
			$product_type = array('Best Selling'=>'best_selling','Featured Products'=>'featured_product','Top Rate'=>'top_rate','Recent Products'=>'recent_product','On Sale'=>'on_sale','Recent Review' => 'recent_review' );
			$product_columns = array(6 ,5 ,4 , 3, 2, 1);
			$show_tab = array(
			                array('recent', esc_html__('Latest Products', 'plant')),
			                array( 'featured_product', esc_html__('Featured Products', 'plant' )),
			                array('best_selling', esc_html__('BestSeller Products', 'plant' )),
			                array('top_rate', esc_html__('TopRated Products', 'plant' )),
			                array('on_sale', esc_html__('Special Products', 'plant' ))
			            );

			/**
			 * pbr_products
			 */
			vc_map( array(
			    "name" => esc_html__("PBR Products", 'plant'),
			    "base" => "pbr_products",
			    'description'=> esc_html__( 'Show products as bestseller, featured in block', 'plant' ),
			    "class" => "",
			   "category" => esc_html__('PBR Woocommerce', 'plant'),
			    "params" => array(

					array(
						"type" => "dropdown",
						"heading" => esc_html__('Category', 'plant'),
						"param_name" => "term_id",
						"value" =>$product_categories_dropdown,	"admin_label" => true
					),
			    	array(
						"type" => "dropdown",
						"heading" => esc_html__("Type", 'plant'),
						"param_name" => "type",
						"value" => $product_type,
						"admin_label" => true,
						"description" => esc_html__("Select columns count.", 'plant')
					),
					array(
						"type" => "dropdown",
						"heading" => esc_html__("Style", 'plant'),
						"param_name" => "style",
						"value" => $product_layout
					),
					array(
						"type" => "dropdown",
						"heading" => esc_html__("Columns count", 'plant'),
						"param_name" => "columns_count",
						"value" => $product_columns,
						"admin_label" => true,
						"description" => esc_html__("Select columns count.", 'plant')
					),
					array(
						"type" => "textfield",
						"heading" => esc_html__("Number of products to show", 'plant'),
						"param_name" => "number",
						"value" => '4'
					),
					array(
						"type" => "textfield",
						"heading" => esc_html__("Extra class name", 'plant'),
						"param_name" => "el_class",
						"description" => esc_html__("If you wish to style particular content element differently, then use this field to add a class name and then refer to it in your css file.", 'plant')
					)
			   	)
			));
			 


		// Category
		vc_map( array(
			'name'        => esc_html__( 'PBR Category', 'plant' ),
			'base'        => 'pbr_category',
			'icon'        => 'icon-wpb-woocommerce',
			'category'    => esc_html__( 'PBR Woocommerce', 'plant' ),
			'description' => esc_html__( 'Display SubCategory', 'plant' ),

			'params' => array(
                array(
                    "type" => "dropdown",
                    "heading" => esc_html__("style", 'plant'),
                    "param_name" => "style",
                    'value' 	=> array(
                        esc_html__('Default', 'plant') => 'default',
                        esc_html__('Group', 'plant') => 'group',
                        esc_html__('ZigZag', 'plant') => 'zigzag',
                    ),
                    'std' => 'default'
                ),
                array(
					"type"        => "attach_image",
					"description" => esc_html__("Upload an image for category", 'plant'),
					"param_name"  => "image",
					"value"       => '',
					'heading'     => esc_html__('Image', 'plant' ),
                    'dependency' => array(
                        'element' => 'style',
                        'value' => array('default')
                    ),
				),
                array(
                    "type"        => "textfield",
                    "heading"     => esc_html__("Title", 'plant'),
                    "param_name"  => "title",
                    "description" => esc_html__("Title for category", 'plant'),
                    'dependency' => array(
                        'element' => 'style',
                        'value' => array('default')
                    ),
                ),
				array(
					'type' 			=> 'dropdown',
					'heading' 		=> esc_html__( 'Category', 'plant' ),
					'value' 		=> $product_categories_dropdown,
					"admin_label" 	=> true,
					'param_name' 	=> 'category',
					'description' 	=> esc_html__( 'Product category list', 'plant' ),
                    'dependency' => array(
                        'element' => 'style',
                        'value' => array('default')
                    ),
				),
                array(
                    'type' => 'param_group',
                    'value' => '',
                    'param_name' => 'items',
                    // Note params is mapped inside param-group:
                    'params' => array(
                        array(
                            "type" => "attach_image",
                            "heading" => esc_html__("Photo for slide", 'plant'),
                            "param_name" => "gr_photo_slider",
                            "value" => '',
                        ),
                        array(
                            "type"        => "textfield",
                            "heading"     => esc_html__("Title", 'plant'),
                            "param_name"  => "gr_title",
                            "description" => esc_html__("Title for category", 'plant'),
                        ),
                        array(
                            "type"        => "textfield",
                            "heading"     => esc_html__("Description", 'plant'),
                            "param_name"  => "gr_description",
                            "description" => esc_html__("Description for category", 'plant'),
                        ),
                        array(
                            'type' 			=> 'dropdown',
                            'heading' 		=> esc_html__( 'Category', 'plant' ),
                            'value' 		=> $product_categories_dropdown,
                            "admin_label" 	=> true,
                            'param_name' 	=> 'gr_category',
                            'description' 	=> esc_html__( 'Product category list', 'plant' ),
                        ),

                    ),
                    'dependency' => array(
                        'element' => 'style',
                        'value' => array('group','zigzag')
                    ),
                ),
				array(
					"type"        => "textfield",
					"heading"     => esc_html__("Extra class name", 'plant'),
					"param_name"  => "el_class",
					"description" => esc_html__("If you wish to style particular content element differently, then use this field to add a class name and then refer to it in your css file.", 'plant')
				)
			)
		) );

		// Product Item Deal
		vc_map( array(
			'name'        => esc_html__( 'PBR To Day Deal', 'plant' ),
			'base'        => 'pbr_today_deal',
			'icon'        => 'icon-wpb-woocommerce',
			'category'    => esc_html__( 'PBR Woocommerce', 'plant' ),
			'description' => esc_html__( 'Display Product Item deal', 'plant' ),

			'params' => array(
				array(
	                "type" => "textfield",
	                "class" => "",
	                "heading" => esc_html__('Title', 'plant'),
	                "param_name" => "title",
	            ),

	            array(
	                "type" => "textfield",
	                "class" => "",
	                "heading" => esc_html__('Sub Title', 'plant'),
	                "param_name" => "subtitle",
	            ),

	            array(
					"type" => "textarea",
					"heading" => esc_html__("information", 'plant'),
					"param_name" => "description",
					"value" => 'Your Description Here',
					'description'	=> esc_html__('Allow  put html tags', 'plant' )
				),

	            array(
					"type" => "dropdown",
					"heading" => esc_html__("style", 'plant'),
					"param_name" => "layer_style",
					'value' 	=> array(
						esc_html__('Style v1', 'plant') => 'style-v1',
						esc_html__('Style v2', 'plant') => 'style-v2',
					),
					'std' => ''
				), 

	            array(
					"type"        => "attach_image",
					"description" => esc_html__("Upload an image", 'plant'),
					"param_name"  => "photo",
					"value"       => '',
					'heading'     => esc_html__('Image', 'plant' )
				),

				array(
				    'type' => 'textfield',
				    'heading' => esc_html__( 'Date Expired', 'plant' ),
				    'param_name' => 'input_datetime',
				    'description' => esc_html__( 'Select font color', 'plant' ),
				),

				array(
	                "type" => "textfield",
	                "class" => "",
	                "heading" => esc_html__('Text button', 'plant'),
	                "param_name" => "text_button",
	            ),

				array(
					'type' => 'vc_link',
					'heading' => esc_html__( 'URL (Link)', 'plant' ),
					'param_name' => 'link_button',
					'description' => esc_html__( 'Add link to button.', 'plant' ),
				),

				array(
					"type"        => "textfield",
					"heading"     => esc_html__("Extra class name", 'plant'),
					"param_name"  => "el_class",
					"description" => esc_html__("If you wish to style particular content element differently, then use this field to add a class name and then refer to it in your css file.", 'plant')
				),
			)
		) );

		// Custom content
		vc_map( array(
			'name'        => esc_html__( 'PBR Custom Content', 'plant' ),
			'base'        => 'pbr_custom_content',
			'icon'        => 'icon-wpb-woocommerce',
			'category'    => esc_html__( 'PBR Woocommerce', 'plant' ),
			'description' => esc_html__( 'Display content banner', 'plant' ),

			'params' => array(
				array(
	                "type" => "textfield",
	                "class" => "",
	                "heading" => esc_html__('Title', 'plant'),
	                "param_name" => "title",
	            ),

	            array(
	                "type" => "textfield",
	                "class" => "",
	                "heading" => esc_html__('Sub Title', 'plant'),
	                "param_name" => "subtitle",
	            ),

	            array(
					"type"        => "attach_image",
					"description" => esc_html__("Upload an image", 'plant'),
					"param_name"  => "image_banner",
					"value"       => '',
					'heading'     => esc_html__('Image', 'plant' )
				),

				array(
					"type"        => "textfield",
					"heading"     => esc_html__("Extra class name", 'plant'),
					"param_name"  => "el_class",
					"description" => esc_html__("If you wish to style particular content element differently, then use this field to add a class name and then refer to it in your css file.", 'plant')
				),
				
				array(
					'type' => 'dropdown',
					'heading' => esc_html__( 'Display button shop now', 'plant' ),
					'param_name' => 'button',
					'value' => array(
						esc_html__('Yes', 'plant') 	=> 1,
						esc_html__('No', 'plant') 	=> 0
					),
					'description' =>  esc_html__( 'Display call to action button', 'plant' ),
					'std' => 1
				),

	            array(
					"type" => "textarea",
					"heading" => esc_html__("information", 'plant'),
					"param_name" => "description",
					"value" => 'Your Description Here',
					'description'	=> esc_html__('Allow  put html tags', 'plant' )
				),
			)
		) );

		//Product categories tab
		vc_map( array(
			'name' => esc_html__( 'PBR Product Categories Tab ', 'plant' ),
			'base' => 'pbr_product_categories_tab',
			'icon' => 'icon-wpb-woocommerce',
			'category' => esc_html__( 'PBR Woocommerce', 'plant' ),
			'description' => esc_html__( 'Display product categories tab', 'plant' ),
			'params' => array(
				array(
					'type' => 'textfield',
					'heading' => esc_html__( 'Title', 'plant' ),
					'param_name' => 'title',
					'description' => esc_html__( 'Enter title ', 'plant' ),
				),
		        array(
					'type' => 'dropdown',
					'heading' => esc_html__( 'Product type', 'plant' ),
					'value' => $options,
					'param_name' => 'product_type',
					'default' => 'recent_products',
					'description' => esc_html__( 'Select Product type', 'plant' ),
				),
				array(
				    'type' => 'autocomplete',
				    'heading' => esc_html__( 'Categories', 'plant' ),
				    'value' => '',
				    'param_name' => 'categories',
				    "admin_label" => true,
				    'description' => esc_html__( 'Select Category', 'plant' ),
				    'settings' => array(
				     'multiple' => true,
				     'unique_values' => true,
				     // In UI show results except selected. NB! You should manually check values in backend
				    ),
			   	),
				array(
					'type' => 'textfield',
					'heading' => esc_html__( 'Per page', 'plant' ),
					'value' => 12,
					'param_name' => 'per_page',
					'description' => esc_html__( 'How much items per page to show', 'plant' ),
				),
				array(
					'type' => 'dropdown',
					'heading' => esc_html__( 'Columns', 'plant' ),
					'value' => array(1,2,3,4,5,6),
					'param_name' => 'columns',
					'description' => esc_html__( 'How much columns grid', 'plant' ),
				),
				array(
					"type"        => "textfield",
					"heading"     => esc_html__('Extra class name', 'plant'),
					"param_name"  => "el_class",
					"description" => esc_html__('If you wish to style particular content element differently, then use this field to add a class name and then refer to it in your css file.', 'plant')
				)
			)
		) );

		/**
		 * pbr_all_products
		 */
		vc_map( array(
		    "name" => esc_html__("PBR Products Tabs", 'plant'),
		    "base" => "pbr_tabs_products",
		    'description'	=> esc_html__( 'Display BestSeller, TopRated ... Products In tabs', 'plant' ),
		    "class" => "",
		    "category" => esc_html__('PBR Woocommerce', 'plant'),
		    "params" => array(
		    	array(
					"type" => "textfield",
					"heading" => esc_html__("Title", 'plant'),
					"param_name" => "title",
					"value" => ''
				),
				 array(
	                "type" => "textfield",
	                "class" => "",
	                "heading" => esc_html__('Sub Title', 'plant'),
	                "param_name" => "subtitle",
	            ),
				array(
		            "type" => "sorted_list",
		            "heading" => esc_html__("Show Tab", 'plant'),
		            "param_name" => "show_tab",
		            "description" => esc_html__("Control teasers look. Enable blocks and place them in desired order.", 'plant'),
		            "value" => "recent,featured_product,best_selling",
		            "options" => $show_tab
		        ),
		        array(
					"type" => "dropdown",
					"heading" => esc_html__("Style", 'plant'),
					"param_name" => "style",
					"value" => $product_layout
				),
				array(
					"type" => "textfield",
					"heading" => esc_html__("Number of products to show", 'plant'),
					"param_name" => "number",
					"value" => '4'
				),
				array(
					"type" => "dropdown",
					"heading" => esc_html__("Columns count", 'plant'),
					"param_name" => "columns_count",
					"value" => $product_columns,
					"description" => esc_html__("Select columns count.", 'plant')
				),
				array(
					"type" => "textfield",
					"heading" => esc_html__("Extra class name", 'plant'),
					"param_name" => "el_class",
					"description" => esc_html__("If you wish to style particular content element differently, then use this field to add a class name and then refer to it in your css file.", 'plant')
				)
		   	)
		));

            /**
             * SLider Products
             */
            vc_map( array(
                "name" => esc_html__("PBR Slider Products", 'plant'),
                "base" => "pbr_slider_products",
                'description'	=> esc_html__( 'Display Slider Products', 'plant' ),
                "class" => "",
                "category" => esc_html__('PBR Woocommerce', 'plant'),
                "params" => array(
                    array(
                        "type" => "dropdown",
                        "heading" => esc_html__("Style", 'plant'),
                        "param_name" => "slider_style",
                        'value' 	=> array(
                            esc_html__('Style v1', 'plant') => 'style-v1',
                            esc_html__('Style v2', 'plant') => 'style-v2',
                            esc_html__('Style v3', 'plant') => 'style-v3',
                        ),
                        'std' => 'style-v1'
                    ),
                    array(
                        'type' => 'param_group',
                        'value' => '',
                        'param_name' => 'items',
                        // Note params is mapped inside param-group:
                        'params' => array(
                            array(
                                "type" => "attach_image",
                                "heading" => esc_html__("Photo for slide", 'plant'),
                                "param_name" => "photo_slider",
                                "value" => '',
                            ),
                            array(
                                'type' => 'attach_image',
                                'value' => '',
                                'heading' => 'Photo for product',
                                'param_name' => 'photo_product',
                                'dependency' => array(
                                    'element' => 'slider_style',
                                    'value' => array('style-v1')
                                ),
                            ),
                            array(
                                "type" => "dropdown",
                                "heading" => esc_html__("Product", 'plant'),
                                "param_name" => "product",
                                "value" => plant_get_all_products(),
                                "description" => esc_html__("Select product display on slide.", 'plant')
                            ),

                        ),
                    ),
                    array(
                        "type" => "textfield",
                        "heading" => esc_html__("Extra class name", 'plant'),
                        "param_name" => "el_class",
                        "description" => esc_html__("If you wish to style particular content element differently, then use this field to add a class name and then refer to it in your css file.", 'plant')
                    )
                )
            ));

			$allpages = array( esc_html__( ' --- Do not show --- ', 'plant' ) => '' );
			if ( is_admin() ) {
				$args = array(
					'sort_order' => 'desc',
					'sort_column' => 'date',
					'post_type' => 'page',
					'post_status' => 'publish'
				);
				$pages = get_pages($args);
				if ( !empty($pages) ) {
					foreach ($pages as $page) {
						$allpages[$page->post_title] = $page->post_name;
					}
				}
			}

		}
	}	

	/**
	  * Register Woocommerce Vendor which will register list of shortcodes
	  */
	function plant_fnc_init_vc_woocommerce_vendor(){

		$vendor = new Plant_VC_Woocommerce();
		add_action( 'vc_after_set_mode', array(
			$vendor,
			'load'
		) );

	}
	add_action( 'after_setup_theme', 'plant_fnc_init_vc_woocommerce_vendor' , 9 );   
}	


if( class_exists("WPBakeryShortCode") ){
	
	class WPBakeryShortCode_PBR_Tabs_Products extends WPBakeryShortCode {

		public function getListQuery( $atts ){ 
			$this->atts  = $atts; 
			$list_query = array();
			$types = explode(',', $this->atts['show_tab']);
			foreach ($types as $type) {
				$list_query[$type] = $this->getTabTitle($type);
			}


			return $list_query;
		}

		public function getTabTitle($type){ 
			switch ($type) {
				case 'recent':
					return array('title'=>esc_html__('Latest Products', 'plant'),'title_tab'=>esc_html__('Latest', 'plant'));
				case 'featured_product':
					return array('title'=>esc_html__('Featured Products', 'plant'),'title_tab'=>esc_html__('Featured', 'plant'));
				case 'top_rate':
					return array('title'=> esc_html__('Top Rated Products', 'plant'),'title_tab'=>esc_html__('Top Rated', 'plant'));
				case 'best_selling':
					return array('title'=>esc_html__('BestSeller Products', 'plant'),'title_tab'=>esc_html__('BestSeller', 'plant'));
				case 'on_sale':
					return array('title'=>esc_html__('Special Products', 'plant'),'title_tab'=>esc_html__('Special', 'plant'));
			}
		}
	}

	//====================================================
	class WPBakeryShortCode_Pbr_products extends WPBakeryShortCode {}	 
	class WPBakeryShortCode_Pbr_today_deal extends WPBakeryShortCode {}
	class WPBakeryShortCode_Pbr_product_categories_tab extends WPBakeryShortCode {}
	class WPBakeryShortCode_Pbr_Category extends WPBakeryShortCode {}
	class WPBakeryShortCode_pbr_custom_content extends WPBakeryShortCode {}
	class WPBakeryShortCode_pbr_slider_products extends WPBakeryShortCode {}

 }
	