<?php
/* ---------------------------------------------------------------------------
 * WooCommerce - Function get Query
 * --------------------------------------------------------------------------- */
function plant_fnc_woocommerce_query($type, $post_per_page = -1, $cat = '')
{
    global $woocommerce, $wp_query;
    $paged = (get_query_var('paged')) ? get_query_var('paged') : 1;
    $orderby = (get_query_var('orderby')) ? get_query_var('orderby') : null;
    $args = array(
        'post_type' => 'product',
        'posts_per_page' => $post_per_page,
        'post_status' => 'publish',
        'paged' => $paged,
        'orderby' => $orderby
    );

    if (isset($args['orderby'])) {
        if ('price' == $args['orderby']) {
            $args = array_merge($args, array(
                'meta_key' => '_price',
                'orderby' => 'meta_value_num'
            ));
        }
        if ('featured' == $args['orderby']) {
            $args = array_merge($args, array(
                'meta_key' => '_featured',
                'orderby' => 'meta_value'
            ));
        }
        if ('sku' == $args['orderby']) {
            $args = array_merge($args, array(
                'meta_key' => '_sku',
                'orderby' => 'meta_value'
            ));
        }
    }

    switch ($type) {
        case 'best_selling':
            $args['meta_key'] = 'total_sales';
            $args['orderby'] = 'meta_value_num';
            $args['ignore_sticky_posts'] = 1;
            $args['meta_query'] = array();
            $args['meta_query'][] = $woocommerce->query->stock_status_meta_query();
            $args['meta_query'][] = $woocommerce->query->visibility_meta_query();
            break;
        case 'featured_product':
            $product_ids_featured = wc_get_featured_product_ids();
            $args['post__in'] = $product_ids_featured;
            break;
        case 'top_rate':
            //
            $args['meta_query'] = array();
            $args['meta_query'][] = $woocommerce->query->stock_status_meta_query();
            $args['meta_query'][] = $woocommerce->query->visibility_meta_query();
            break;
        case 'recent_product':
            $args['meta_query'] = array();
            $args['meta_query'][] = $woocommerce->query->stock_status_meta_query();
            break;
        case 'deals':

            $args['meta_query'] = array();
            $args['meta_query'][] = $woocommerce->query->stock_status_meta_query();
            $args['meta_query'][] = $woocommerce->query->visibility_meta_query();
            $args['meta_query'][] = array(

                array( // Variable products type
                    'key' => '_sale_price_dates_to',
                    'value' => time(),
                    'compare' => '>',
                    'type' => 'numeric'
                )
            );


            break;
        case 'on_sale':
            $product_ids_on_sale = wc_get_product_ids_on_sale();
            $product_ids_on_sale[] = 0;
            $args['post__in'] = $product_ids_on_sale;
            break;
        case 'recent_review':
            if ($post_per_page == -1) $_limit = 4;
            else $_limit = $post_per_page;
            global $wpdb;
            $query = "SELECT c.comment_post_ID FROM {$wpdb->prefix}posts p, {$wpdb->prefix}comments c WHERE p.ID = c.comment_post_ID AND c.comment_approved > 0 AND p.post_type = 'product' AND p.post_status = 'publish' AND p.comment_count > 0 ORDER BY c.comment_date ASC";
            $results = $wpdb->get_results($query, OBJECT);
            $_pids = array();
            foreach ($results as $re) {
                if (!in_array($re->comment_post_ID, $_pids))
                    $_pids[] = $re->comment_post_ID;
                if (count($_pids) == $_limit)
                    break;
            }

            $args['meta_query'] = array();
            $args['meta_query'][] = $woocommerce->query->stock_status_meta_query();
            $args['meta_query'][] = $woocommerce->query->visibility_meta_query();
            $args['post__in'] = $_pids;

            break;
    }

    if (!empty($cat) && !is_array($cat)) {
        $cat = array($cat);
    }
    if (!empty($cat) && is_array($cat)) {

        if (isset($cat[0]) && !is_numeric($cat[0])) {
            $terms = array();
            foreach ($cat as $ct) {
                $ocategory = get_term_by('slug', $ct, 'product_cat');

                if ($ocategory) {
                    $terms[] = $ocategory->term_id;
                }
            }
            $cat = $terms;
        }

        $args['tax_query'] = array(
            array(
                'taxonomy' => 'product_cat',
                'field' => 'term_id', //This is optional, as it defaults to 'term_id'
                'terms' => $cat,
                'operator' => 'IN' // Possible values are 'IN', 'NOT IN', 'AND'.
            )
        );
    }

    $query = new WP_Query($args);

    wp_reset_postdata();

    return $query;

}

function plant_fnc_get_review_counting()
{

    global $post;
    $output = array();

    for ($i = 1; $i <= 5; $i++) {
        $args = array(
            'post_id' => ($post->ID),
            'meta_query' => array(
                array(
                    'key' => 'rating',
                    'value' => $i
                )
            ),
            'count' => true
        );
        $output[$i] = get_comments($args);
    }
    return $output;
}

function plant_fnc_price($price)
{
    return $price;
}

function plant_fnc_woocommerce_getcategorychilds($parent_id, $array, $level, &$dropdown)
{
    foreach ($array as $key => $value) {
        if ($value->category_parent == $parent_id) {
            $data = array(
                str_repeat("- ", $level) . $value->name . '(' . $value->term_id . ')' => $value->slug,
            );
            $dropdown = array_merge($dropdown, $data);
            unset($array[$key]);
            plant_fnc_woocommerce_getcategorychilds($value->term_id, $array, $level + 1, $dropdown);
        }
    }
}


if (!function_exists('plant_fnc_woocommerce_content')) {

    /**
     * Output WooCommerce content.
     *
     * This function is only used in the optional 'woocommerce.php' template
     * which people can add to their themes to add basic woocommerce support
     * without hooks or modifying core templates.
     *
     */
    function plant_fnc_woocommerce_content()
    {

        $status = isset($_GET['sidebar']) && !empty($_GET['sidebar']) ? $_GET['sidebar'] : '';
        $sort = isset($_GET['sort']) && !empty($_GET['sort']) ? $_GET['sort'] : 'grid';
        $layout = plant_fnc_theme_options('woocommerce-archive-layout', 'fullwidth');

        if (($status == 'left') || ($status == 'right') || ($layout == 'mainright') || ($layout == 'leftmain')) {
            if ($sort == 'grid') {
                $class = 'col-lg-3 col-md-6 col-sm-6';
            } else {
                $class = 'col-lg-12 col-md-12 col-sm-12';
            }
            $class_view = 'display-mode-default';
        } else {
            if ($sort == 'grid') {
                $class = 'col-lg-5 col-md-4 col-sm-6';
            } else {
                $class = 'col-lg-12 col-md-12 col-sm-12';
            }
            $class_view = 'display-mode-full';
        }

        if (is_singular('product')) {

            while (have_posts()) : the_post();

                wc_get_template_part('content', 'single-product');

            endwhile;

        } else {
            ?>
            <div class="category-header clearfix">
                <?php do_action('woocommerce_archive_description'); ?>
            </div>
            <div class="category-content">
                <?php if (have_posts()) : ?>
                    <div class="products-top-wrap">
                        <div class="box-left">
                            <?php if (class_exists('PbrThemerSetting')): ?>
                                <div class="display-mode <?php echo esc_html($class_view); ?>">
                                    <button class="btn-grid <?php if ($sort == 'grid') {
                                        echo esc_attr('active');
                                    } ?>" value="grid" name="display" type="submit"><i
                                                class="icons-grid"></i></button>
                                    <button class="btn-list <?php if ($sort == 'list') {
                                        echo esc_attr('active');
                                    } ?>" value="list" name="display" type="submit"><i
                                                class="icons-list"></i></button>
                                </div>
                            <?php endif; ?>
                            <div class="results"> <?php do_action('woocommerce_after_shop_loop'); ?></div>
                        </div>
                        <div class="box-right">
                            <?php
                            if ((($layout == 'fullwidth') && empty($status)) || ($status == 'full')) {
                                ?>
                                <div class="btn-filter"
                                     data-toggle="filter"><?php echo esc_html__('Filter', 'plant'); ?> <i
                                            class="ion-android-options"></i>
                                </div>
                            <?php } ?>
                            <div class="select-filter">
                                <span><?php echo esc_html__('Sort by', 'plant'); ?> :</span>
                                <?php do_action('woocommerce_before_shop_loop'); ?>
                            </div>
                        </div>
                    </div>

                    <div class="products <?php if ($sort == 'grid') {
                        echo esc_attr('products-grid');
                    } else {
                        echo esc_attr('products-list');
                    } ?>">
                        <div class="row">
                            <?php while (have_posts()) : the_post(); ?>
                            <?php global $product, $woocommerce ?>
                                <?php if (class_exists('PbrThemerSetting')): ?>
                                    <div class="item <?php echo esc_html($class); ?>">
                                        <div class="product-block clearfix"
                                             data-product-id="<?php echo esc_attr(get_the_ID()); ?>">
                                            <figure class="image">
                                                <?php woocommerce_show_product_loop_sale_flash(); ?>
                                                <h5 class="title-h5"><a
                                                            href="<?php echo esc_url(get_the_permalink()); ?>"
                                                            class="product-image">
                                                        <?php
                                                        /**
                                                         * woocommerce_before_shop_loop_item_title hook
                                                         *
                                                         * @hooked woocommerce_show_product_loop_sale_flash - 10
                                                         * @hooked woocommerce_template_loop_product_thumbnail - 10
                                                         */
                                                        remove_action('woocommerce_before_shop_loop_item_title', 'woocommerce_show_product_loop_sale_flash', 10);
                                                        remove_action('woocommerce_before_shop_loop_item_title', 'woocommerce_template_loop_product_thumbnail', 10);
                                                        add_action('woocommerce_before_shop_loop_item_title', 'plant_woocommerce_template_loop_product_thumbnail', 11);
                                                        do_action('woocommerce_before_shop_loop_item_title');
                                                        ?>
                                                    </a></h5>
                                                <?php
                                                $cart = plant_fnc_theme_options('woo-show-minicart', 0);
                                                $wishlist = plant_fnc_theme_options('show-wishlist', 0);
                                                $quickview = plant_fnc_theme_options('is-quickview', 0);
                                                if (($cart == 1) || ($wishlist == 1) || $quickview == 1):
                                                    ?>
                                                    <div class="button-action">
                                                        <div class="button-groups">
                                                            <?php if ($cart) { ?>
                                                                <div class="item">
                                                                    <?php do_action('woocommerce_after_shop_loop_item'); ?>
                                                                    <?php
                                                                    $action_add = 'yith-woocompare-add-product';
                                                                    ?>
                                                                </div>
                                                            <?php } ?>
                                                            <?php if ($wishlist && class_exists('YITH_WCWL')) { ?>
                                                                <div class="item">
                                                                    <?php
                                                                    echo do_shortcode('[yith_wcwl_add_to_wishlist]');
                                                                    ?>
                                                                </div>
                                                            <?php } ?>
                                                            <?php if ($quickview && class_exists('WooCommerce')) { ?>
                                                                <div class="item">
                                                                    <div class="quick-view">
                                                                        <a href="#" class="quickview"
                                                                           data-productslug="<?php echo trim($product->get_slug()); ?>"
                                                                           data-toggle="modal"
                                                                           data-target="#pbr-quickview-modal">
                                                                            <span><i class="icon-quickview"> </i></span>
                                                                        </a>
                                                                    </div>
                                                                </div>
                                                            <?php } ?>
                                                        </div>
                                                    </div>
                                                <?php endif; ?>
                                            </figure>
                                            <div class="caption">
                                                <div class="meta">
                                                    <h3 class="name title-h5"><a
                                                                href="<?php the_permalink(); ?>"><?php the_title(); ?></a>
                                                    </h3>
                                                    <?php
                                                    /**
                                                     * woocommerce_after_shop_loop_item_title hook
                                                     *
                                                     * @hooked woocommerce_template_loop_rating - 5
                                                     * @hooked woocommerce_template_loop_price - 10
                                                     */
                                                    do_action('woocommerce_after_shop_loop_item_title');

                                                    ?>
                                                </div>
                                            </div>
                                            <div class="pro-list">
                                                <h1 class="pro-name"><a
                                                            href="<?php echo esc_url(get_the_permalink()); ?>"><?php the_title(); ?></a>
                                                </h1>
                                                <div class="pro-star">
                                                    <div class="star-rating">
                                                        <?php echo wc_get_rating_html($product->get_average_rating()); ?>
                                                    </div>
                                                </div>
                                                <div class="pro-price">
                                                    <?php if ($price_html = $product->get_price_html()) : ?>
                                                        <span class="price"><?php echo trim($price_html); ?></span>
                                                    <?php endif; ?>
                                                </div>
                                                <div class="pro-desc">
                                                    <p>
                                                        <?php echo get_the_excerpt(); ?>
                                                    </p>
                                                </div>
                                                <div class="pro-action">
                                                    <?php do_action('woocommerce_after_shop_loop_item'); ?>
                                                    <?php
                                                    $action_add = 'yith-woocompare-add-product';
                                                    $url_args = array(
                                                        'action' => $action_add,
                                                        'id' => get_the_ID()
                                                    );
                                                    ?>

                                                    <?php
                                                    if (class_exists('YITH_WCWL')) {
                                                        echo do_shortcode('[yith_wcwl_add_to_wishlist]');
                                                    }
                                                    ?>

                                                    <?php if (plant_fnc_theme_options('is-quickview', true)) { ?>
                                                        <div class="quick-view">
                                                            <a href="#" class="quickview"
                                                               data-productslug="<?php echo trim($product->get_slug()); ?>"
                                                               data-toggle="modal" data-target="#pbr-quickview-modal">
                                                                <span><i class="icon-quickview"> </i></span>
                                                            </a>
                                                        </div>
                                                    <?php } ?>
                                                </div>
                                                <div class="pro-share">
                                                    <span><?php echo esc_html__('Share this', 'plant'); ?> :</span>
                                                    <?php pbr_themer_get_template_part('sharebox'); ?>
                                                </div>
                                            </div>
                                        </div>
                                    </div>
                                <?php else: ?>
                                    <?php wc_get_template_part('content', 'product'); ?>

                                <?php endif; ?>
                            <?php endwhile; // end of the loop. ?>
                        </div>
                    </div>
                    <div class="results results_bottom"> <?php do_action('woocommerce_after_shop_loop'); ?></div>

                <?php elseif (!woocommerce_product_subcategories(array('before' => woocommerce_product_loop_start(false), 'after' => woocommerce_product_loop_end(false)))) : ?>

                    <?php wc_get_template('loop/no-products-found.php'); ?>


                <?php endif; ?>

            </div>
            <?php
        }
    }
}

function plant_fnc_woocommerce_before_shop_loop_item_title()
{

    global $product;

    if ($product->get_regular_price()) {
        $percentage = round((($product->get_regular_price() - $product->get_sale_price()) / $product->get_regular_price()) * 100);
        echo '<span class="product-sale-label">-' . trim($percentage) . '%</span>';
    }

}

function plant_fnc_woocommerce_product_type_title($product_type)
{
    switch ($product_type) {
        case 'recent':
            return esc_html__('Latest Products', 'plant');
            break;

        case 'featured_product':
            return esc_html__('Featured Products', 'plant');
            break;

        case 'best_selling':
            return esc_html__('BestSeller Products', 'plant');
            break;

        case 'top_rate':
            return esc_html__('TopRated Products', 'plant');
            break;

        case 'on_sale':
            return esc_html__('Special Products', 'plant');
            break;
    }

}
