<?php
/**
 * Cart Page
 *
 * This template can be overridden by copying it to yourtheme/woocommerce/cart/cart.php.
 *
 * HOWEVER, on occasion WooCommerce will need to update template files and you
 * (the theme developer) will need to copy the new files to your theme to
 * maintain compatibility. We try to do this as little as possible, but it does
 * happen. When this occurs the version of the template file will be bumped and
 * the readme will list any important changes.
 *
 * @see     https://docs.woocommerce.com/document/template-structure/
 * @package WooCommerce/Templates
 * @version 3.7.0
 */

defined('ABSPATH') || exit;

wc_print_notices();

do_action('woocommerce_before_cart'); ?>

<!-- END-HEADER -->
<div class="cart-page">
    <div class="container">
        <div class="inner row">
            <form class="woocommerce-cart-form" action="<?php echo esc_url(wc_get_cart_url()); ?>" method="post">
                <?php do_action('woocommerce_before_cart_table'); ?>
                <div class="shop_table shop_table_responsive cart woocommerce-cart-form__contents row">
                    <div class="content-left col-md-8 col-sm-8">
                        <div class="title-heading">
                            <span><?php echo esc_html__('Shopping Cart', 'plant'); ?></span>
                        </div>
                        <div class="content-product-list">
                            <?php do_action('woocommerce_before_cart_contents'); ?>

                            <?php
                            foreach (WC()->cart->get_cart() as $cart_item_key => $cart_item) {
                                $_product = apply_filters('woocommerce_cart_item_product', $cart_item['data'], $cart_item, $cart_item_key);
                                $product_id = apply_filters('woocommerce_cart_item_product_id', $cart_item['product_id'], $cart_item, $cart_item_key);

                                if ($_product && $_product->exists() && $cart_item['quantity'] > 0 && apply_filters('woocommerce_cart_item_visible', true, $cart_item, $cart_item_key)) {
                                    $product_permalink = apply_filters('woocommerce_cart_item_permalink', $_product->is_visible() ? $_product->get_permalink($cart_item) : '', $cart_item, $cart_item_key);
                                    ?>
                                    <div class="product-block">
                                        <div class="product-image">
                                            <div class="image">
                                                <?php
                                                $thumbnail = apply_filters('woocommerce_cart_item_thumbnail', $_product->get_image(), $cart_item, $cart_item_key);

                                                if (!$product_permalink) {
                                                    echo wp_kses_post($thumbnail);
                                                } else {
                                                    printf('<a href="%s">%s</a>', esc_url($product_permalink), wp_kses_post($thumbnail));
                                                }
                                                ?>
                                            </div>
                                            <div class="product-name">
                                                <?php
                                                if (!$product_permalink) {
                                                    echo wp_kses_post(apply_filters('woocommerce_cart_item_name', $_product->get_name(), $cart_item, $cart_item_key) . '&nbsp;');
                                                } else {
                                                    echo wp_kses_post(apply_filters('woocommerce_cart_item_name', sprintf('<a href="%s">%s</a>', esc_url($product_permalink), $_product->get_name()), $cart_item, $cart_item_key));
                                                }

                                                do_action('woocommerce_after_cart_item_name', $cart_item, $cart_item_key);

                                                // Meta data.
                                                echo wc_get_formatted_cart_item_data($cart_item); // PHPCS: XSS ok.

                                                // Backorder notification.
                                                if ($_product->backorders_require_notification() && $_product->is_on_backorder($cart_item['quantity'])) {
                                                    echo wp_kses_post(apply_filters('woocommerce_cart_item_backorder_notification', '<p class="backorder_notification">' . esc_html__('Available on backorder', 'plant') . '</p>'));
                                                }
                                                ?>
                                                <div class="quantity">
                                                    <?php
                                                    if ($_product->is_sold_individually()) {
                                                        $product_quantity = sprintf('1 <input type="hidden" name="cart[%s][qty]" value="1" />', $cart_item_key);
                                                    } else {
                                                        $product_quantity = woocommerce_quantity_input(array(
                                                            'input_name' => "cart[{$cart_item_key}][qty]",
                                                            'input_value' => $cart_item['quantity'],
                                                            'max_value' => $_product->get_max_purchase_quantity(),
                                                            'min_value' => '0',
                                                            'product_name' => $_product->get_name(),
                                                        ), $_product, false);
                                                    }

                                                    echo apply_filters('woocommerce_cart_item_quantity', $product_quantity, $cart_item_key, $cart_item); // PHPCS: XSS ok.
                                                    ?>
                                                </div>
                                            </div>
                                        </div>
                                        <div class="product-price">
                                            <?php
                                            // @codingStandardsIgnoreLine
                                            echo apply_filters('woocommerce_cart_item_remove_link', sprintf(
                                                '<a href="%s" class="remove" aria-label="%s" data-product_id="%s" data-product_sku="%s"><i class="pe-7s-close"></i></a>',
                                                esc_url(wc_get_cart_remove_url($cart_item_key)),
                                                esc_html__('Remove this item', 'plant'),
                                                esc_attr($product_id),
                                                esc_attr($_product->get_sku())
                                            ), $cart_item_key);
                                            ?>
                                            <div class="price"><?php
                                                echo apply_filters('woocommerce_cart_item_price', WC()->cart->get_product_price($_product), $cart_item, $cart_item_key); // PHPCS: XSS ok.
                                                ?>
                                            </div>
                                        </div>
                                    </div>
                                    <?php
                                }
                            }
                            ?>
                            <?php do_action('woocommerce_cart_contents'); ?>

                            <div class="action-cart-page">
                                <?php
                                $shop_page_id = wc_get_page_id('shop');
                                $shop_page_url = $shop_page_id ? get_permalink($shop_page_id) : '';
                                ?>
                                <div class="continue-shopping btn-outline btn-lage"><a
                                            href="<?php echo esc_url($shop_page_url); ?>"><?php echo esc_html__('Continue Shopping', 'plant'); ?></a>
                                </div>
                                <button type="submit" class="update-cart btn-direct-outline" name="update_cart"
                                        value="<?php esc_attr_e('Update cart', 'plant'); ?>"><?php esc_html_e('Update cart', 'plant'); ?></button>

                                <?php do_action('woocommerce_cart_actions'); ?>

                                <?php wp_nonce_field('woocommerce-cart', 'woocommerce-cart-nonce'); ?>

                            </div>
                        </div>
                    </div>
                    <div class="content-right col-md-4 col-sm-4">
                        <div class="widget widget-coupon">
                            <div class="title-heading">
                                <span><?php echo esc_html__('Coupon', 'plant'); ?></span>
                            </div>
                        </div>
                        <?php if (wc_coupons_enabled()) { ?>
                            <div class="coupon">
                                <label for="coupon_code"><?php esc_html_e('Coupon:', 'plant'); ?></label> <input
                                        type="text" name="coupon_code" class="input-text" id="coupon_code" value=""
                                        placeholder="<?php esc_attr_e('Coupon code', 'plant'); ?>"/>
                                <button type="submit" class="button" name="apply_coupon"
                                        value="<?php esc_attr_e('Apply coupon', 'plant'); ?>"><?php esc_attr_e('Apply coupon', 'plant'); ?></button>
                                <?php do_action('woocommerce_cart_coupon'); ?>
                            </div>
                        <?php } ?>
                        <div class="cart-collaterals">
                            <?php
                            /**
                             * Cart collaterals hook.
                             *
                             * @hooked woocommerce_cross_sell_display
                             * @hooked woocommerce_cart_totals - 10
                             */
                            do_action('woocommerce_cart_collaterals');
                            ?>
                        </div>

                    </div>
                    <?php do_action('woocommerce_after_cart_table'); ?>
                </div>
            </form>
        </div>
    </div>
</div>

<?php do_action('woocommerce_after_cart'); ?>
