<?php
/**
 * Product quantity inputs
 *
 * This template can be overridden by copying it to yourtheme/woocommerce/global/quantity-input.php.
 *
 * HOWEVER, on occasion WooCommerce will need to update template files and you
 * (the theme developer) will need to copy the new files to your theme to
 * maintain compatibility. We try to do this as little as possible, but it does
 * happen. When this occurs the version of the template file will be bumped and
 * the readme will list any important changes.
 *
 * @see     https://docs.woocommerce.com/document/template-structure/
 * @package WooCommerce/Templates
 * @version 3.6.0
 */

defined('ABSPATH') || exit;

if ($max_value && $min_value === $max_value) {
    ?>
    <div class="quantity hidden">
        <input type="hidden" id="<?php echo esc_attr($input_id); ?>" class="qty"
               name="<?php echo esc_attr($input_name); ?>" value="<?php echo esc_attr($min_value); ?>"/>
    </div>
    <?php
} else {
    /* translators: %s: Quantity. */
    $labelledby = !empty($args['product_name']) ? sprintf(esc_html__('%s quantity', 'plant'), strip_tags($args['product_name'])) : '';

    $label = ! empty( $args['product_name'] ) ? sprintf( esc_html__( '%s quantity', 'plant' ), wp_strip_all_tags( $args['product_name'] ) ) : esc_html__( 'Quantity', 'plant' );
    ?>
    <div class="ct-quantity">
        <div class="quantity">
            <label class="screen-reader-text"
                   for="<?php echo esc_attr($input_id); ?>"><?php echo esc_attr( $label ); ?></label>
            <input
                    type="number"
                    id="<?php echo esc_attr($input_id); ?>"
                    class="input-text qty text"
                    step="<?php echo esc_attr($step); ?>"
                    min="<?php echo esc_attr($min_value); ?>"
                    <?php if ( 0 < $max_value ) { ?>
                        max="<?php echo esc_attr( $max_value ); ?>"
    				<?php } ?>
                    name="<?php echo esc_attr( $input_name ); ?>"
                    value="<?php echo esc_attr( $input_value ); ?>"
                    title="<?php echo esc_attr_x( 'Qty', 'Product quantity input tooltip', 'plant' ); ?>"
                    size="4"
    				<?php if ( $labelledby ) { ?>
                    aria-labelledby="<?php echo esc_attr( $labelledby ); ?>"
				<?php } ?>
            />
            <?php if (is_single()): ?>
                <div class="quantity_actions">
                    <div class="minus btn"><i class="ion-android-remove"></i></div>
                    <div class="plus btn"><i class="ion-android-add"></i></div>
                </div>

            <?php else: ?>
                <div class="quantity_actions">
                    <div class="minus btn"><i class="ion-android-remove"></i></div>
                    <div class="plus btn"><i class="ion-android-add"></i></div>
                </div>
            <?php endif; ?>
        </div>
    </div>


    <?php
}
