<?php
/**
 * Related Products
 *
 * This template can be overridden by copying it to yourtheme/woocommerce/single-product/related.php.
 *
 * HOWEVER, on occasion WooCommerce will need to update template files and you
 * (the theme developer) will need to copy the new files to your theme to
 * maintain compatibility. We try to do this as little as possible, but it does
 * happen. When this occurs the version of the template file will be bumped and
 * the readme will list any important changes.
 *
 * @see        https://docs.woocommerce.com/document/template-structure/
 * @author        WooThemes
 * @package    WooCommerce/Templates
 * @version     3.0.0
 */

if (!defined('ABSPATH')) {
    exit; // Exit if accessed directly
}

global $product, $woocommerce_loop;

if (empty($product) || !$product->exists()) {
    return;
}
$per_page = plant_fnc_theme_options('woo-number-product-single', 8);
$related = wc_get_related_products($product->get_id(),$per_page);

if (sizeof($related) == 0) return;

$args = apply_filters('woocommerce_related_products_args', array(
    'post_type' => 'product',
    'ignore_sticky_posts' => 1,
    'no_found_rows' => 1,
    'posts_per_page' => $per_page,
    'orderby' => $orderby,
    'post__in' => $related,
    'post__not_in' => array($product->get_id())
));

$products = new WP_Query($args);

$woocommerce_loop['columns'] = plant_fnc_theme_options('product-number-columns', 5);


if ($products->have_posts()) :

    $data_slick = '{"arrows": true,"slidesToShow": ' . esc_attr($woocommerce_loop['columns']) . ', "slidesToScroll": 1,
                                "responsive": [ {"breakpoint": 1200, "settings": {"slidesToShow":  3, "slidesToScroll": 1}},
                                {"breakpoint": 1024, "settings": {"slidesToShow": 2, "slidesToScroll": 1}},
                                 {"breakpoint": 480, "settings": {"slidesToShow": 1, "slidesToScroll": 1,"arrows":true}}]}';
    ?>

    <div class="related-products widget widget-carousel">

        <h3 class="widget-title"><span><?php esc_html_e('You May Also Like', 'plant'); ?></span></h3>

        <?php wc_get_template('widget-products/carousel.php', array('loop' => $products, 'columns_count' => $woocommerce_loop['columns'], 'posts_per_page' => $per_page, 'data_slick' => $data_slick)); ?>

    </div>

<?php endif;

wp_reset_postdata();
