<?php
/**
 * Single Product tabs
 *
 * This template can be overridden by copying it to yourtheme/woocommerce/single-product/tabs/tabs.php.
 *
 * HOWEVER, on occasion WooCommerce will need to update template files and you
 * (the theme developer) will need to copy the new files to your theme to
 * maintain compatibility. We try to do this as little as possible, but it does
 * happen. When this occurs the version of the template file will be bumped and
 * the readme will list any important changes.
 *
 * @see    https://docs.woocommerce.com/document/template-structure/
 * @author  WooThemes
 * @package WooCommerce/Templates
 * @version 2.4.0
 */

if (!defined('ABSPATH')) {
    exit;
}

/**
 * Filter tabs and allow third parties to add their own.
 *
 * Each tab is an array containing title, callback and priority.
 * @see woocommerce_default_product_tabs()
 */
$tabs = apply_filters('woocommerce_product_tabs', array());
$layout = plant_fnc_theme_options('woocommerce-single-layout', 'style_1');
$layout_v = (isset($_GET['layout']) && (!empty($_GET['layout']))) ? $_GET['layout'] : '';
if (!empty($tabs)) : ?>

    <?php if (($layout == 'style_3') || ($layout_v == 'style_3')): ?>
        <div class="single-product-tab">
            <div class="cmt-title text-center">
                <ul class="nav nav-tabs text-center v2">
                    <?php foreach ( $tabs as $key => $tab ) : ?>
                        <li class="<?php if($key=='description'){echo esc_attr('active');} ?>">
                            <a href="#tab-<?php echo esc_attr( $key ); ?>"  data-toggle="pill"><?php echo apply_filters( 'woocommerce_product_' . $key . '_tab_title', esc_html( $tab['title'] ), $key ); ?></a>
                        </li>
                    <?php endforeach; ?>
                </ul>
            </div>
            <div class="tab-content">
                <?php foreach ( $tabs as $key => $tab ) : ?>
                    <div class="tab-pane fade in <?php if($key=='description'){echo esc_attr('active');} ?>" id="tab-<?php echo esc_attr( $key ); ?>">
                        <div class="entry-content text-center">
                            <?php if ( isset( $tab['callback'] ) ) { call_user_func( $tab['callback'], $key, $tab ); } ?>
                        </div>

                    </div>
                <?php endforeach; ?>
            </div>
        </div>

    <?php else: ?>
        <div class="pro-tabs">
            <div class="tabs-desc">
                <ul class="navbar-tabs">
                    <?php foreach ($tabs as $key => $tab) : ?>
                        <li class="dropdown">
                            <div class="dropdowndesc">
                                <span><?php echo apply_filters('woocommerce_product_' . $key . '_tab_title', esc_html($tab['title']), $key); ?></span>
                                <i class="icon-caret"></i>
                            </div>
                            <div class="dropdown-menu">
                                <?php if (isset($tab['callback'])) {
                                    call_user_func($tab['callback'], $key, $tab);
                                } ?>
                            </div>
                        </li>
                    <?php endforeach; ?>

                </ul>
            </div>
        </div>
    <?php endif; ?>

<?php endif; ?>